@@ -1,19 +1,20 @@
 /// <reference path='services.ts' />
 
-module ts.NavigationBar {
+/* @internal */
+namespace ts.NavigationBar {
     export function getNavigationBarItems(sourceFile: SourceFile): ts.NavigationBarItem[]  {
         // If the source file has any child items, then it included in the tree
         // and takes lexical ownership of all other top-level items.
-        var hasGlobalNode = false;
+        let hasGlobalNode = false;
 
         return getItemsWorker(getTopLevelNodes(sourceFile), createTopLevelItem);
 
         function getIndent(node: Node): number {
             // If we have a global node in the tree,
             // then it adds an extra layer of depth to all subnodes.
-            var indent = hasGlobalNode ? 1 : 0;
+            let indent = hasGlobalNode ? 1 : 0;
 
-            var current = node.parent;
+            let current = node.parent;
             while (current) {
                 switch (current.kind) {
                     case SyntaxKind.ModuleDeclaration:
@@ -37,31 +38,92 @@ module ts.NavigationBar {
 
             return indent;
         }
-          
+
         function getChildNodes(nodes: Node[]): Node[] {
-            var childNodes: Node[] = [];    
+            let childNodes: Node[] = [];
 
-            for (var i = 0, n = nodes.length; i < n; i++) {
-                var node = nodes[i];
+            function visit(node: Node) {
+                switch (node.kind) {
+                    case SyntaxKind.VariableStatement:
+                        forEach((<VariableStatement>node).declarationList.declarations, visit);
+                        break;
+                    case SyntaxKind.ObjectBindingPattern:
+                    case SyntaxKind.ArrayBindingPattern:
+                        forEach((<BindingPattern>node).elements, visit);
+                        break;
 
-                if (node.kind === SyntaxKind.ClassDeclaration ||
-                    node.kind === SyntaxKind.EnumDeclaration ||
-                    node.kind === SyntaxKind.InterfaceDeclaration ||
-                    node.kind === SyntaxKind.ModuleDeclaration ||
-                    node.kind === SyntaxKind.FunctionDeclaration) {
+                    case SyntaxKind.ExportDeclaration:
+                        // Handle named exports case e.g.:
+                        //    export {a, b as B} from "mod";
+                        if ((<ExportDeclaration>node).exportClause) {
+                            forEach((<ExportDeclaration>node).exportClause.elements, visit);
+                        }
+                        break;
 
-                    childNodes.push(node);
-                }
-                else if (node.kind === SyntaxKind.VariableStatement) {
-                    childNodes.push.apply(childNodes, (<VariableStatement>node).declarations);
+                    case SyntaxKind.ImportDeclaration:
+                        let importClause = (<ImportDeclaration>node).importClause;
+                        if (importClause) {
+                            // Handle default import case e.g.:
+                            //    import d from "mod";
+                            if (importClause.name) {
+                                childNodes.push(importClause);
+                            }
+
+                            // Handle named bindings in imports e.g.:
+                            //    import * as NS from "mod";
+                            //    import {a, b as B} from "mod";
+                            if (importClause.namedBindings) {
+                                if (importClause.namedBindings.kind === SyntaxKind.NamespaceImport) {
+                                    childNodes.push(importClause.namedBindings);
+                                }
+                                else {
+                                    forEach((<NamedImports>importClause.namedBindings).elements, visit);
+                                }
+                            }
+                        }
+                        break;
+
+                    case SyntaxKind.BindingElement:
+                    case SyntaxKind.VariableDeclaration:
+                        if (isBindingPattern((<VariableDeclaration>node).name)) {
+                            visit((<VariableDeclaration>node).name);
+                            break;
+                        }
+                        // Fall through
+                    case SyntaxKind.ClassDeclaration:
+                    case SyntaxKind.EnumDeclaration:
+                    case SyntaxKind.InterfaceDeclaration:
+                    case SyntaxKind.ModuleDeclaration:
+                    case SyntaxKind.FunctionDeclaration:
+                    case SyntaxKind.ImportEqualsDeclaration:
+                    case SyntaxKind.ImportSpecifier:
+                    case SyntaxKind.ExportSpecifier:
+                        childNodes.push(node);
+                        break;
                 }
             }
 
+            //for (let i = 0, n = nodes.length; i < n; i++) {
+            //    let node = nodes[i];
+
+            //    if (node.kind === SyntaxKind.ClassDeclaration ||
+            //        node.kind === SyntaxKind.EnumDeclaration ||
+            //        node.kind === SyntaxKind.InterfaceDeclaration ||
+            //        node.kind === SyntaxKind.ModuleDeclaration ||
+            //        node.kind === SyntaxKind.FunctionDeclaration) {
+
+            //        childNodes.push(node);
+            //    }
+            //    else if (node.kind === SyntaxKind.VariableStatement) {
+            //        childNodes.push.apply(childNodes, (<VariableStatement>node).declarations);
+            //    }
+            //}
+            forEach(nodes, visit);
             return sortNodes(childNodes);
         }
 
         function getTopLevelNodes(node: SourceFile): Node[] {
-            var topLevelNodes: Node[] = [];
+            let topLevelNodes: Node[] = [];
             topLevelNodes.push(node);
 
             addTopLevelNodes(node.statements, topLevelNodes);
@@ -72,8 +134,7 @@ module ts.NavigationBar {
         function sortNodes(nodes: Node[]): Node[] {
             return nodes.slice(0).sort((n1: Declaration, n2: Declaration) => {
                 if (n1.name && n2.name) {
-                    // TODO(jfreeman): How do we sort declarations with computed names?
-                    return (<Identifier>n1.name).text.localeCompare((<Identifier>n2.name).text);
+                    return getPropertyNameForPropertyNameNode(n1.name).localeCompare(getPropertyNameForPropertyNameNode(n2.name));
                 }
                 else if (n1.name) {
                     return 1;
@@ -90,8 +151,7 @@ module ts.NavigationBar {
         function addTopLevelNodes(nodes: Node[], topLevelNodes: Node[]): void {
             nodes = sortNodes(nodes);
 
-            for (var i = 0, n = nodes.length; i < n; i++) {
-                var node = nodes[i];
+            for (let node of nodes) {
                 switch (node.kind) {
                     case SyntaxKind.ClassDeclaration:
                     case SyntaxKind.EnumDeclaration:
@@ -100,13 +160,13 @@ module ts.NavigationBar {
                         break;
 
                     case SyntaxKind.ModuleDeclaration:
-                        var moduleDeclaration = <ModuleDeclaration>node;
+                        let moduleDeclaration = <ModuleDeclaration>node;
                         topLevelNodes.push(node);
                         addTopLevelNodes((<Block>getInnermostModule(moduleDeclaration).body).statements, topLevelNodes);
                         break;
 
                     case SyntaxKind.FunctionDeclaration:
-                        var functionDeclaration = <FunctionLikeDeclaration>node;
+                        let functionDeclaration = <FunctionLikeDeclaration>node;
                         if (isTopLevelFunctionDeclaration(functionDeclaration)) {
                             topLevelNodes.push(node);
                             addTopLevelNodes((<Block>functionDeclaration.body).statements, topLevelNodes);
@@ -140,18 +200,17 @@ module ts.NavigationBar {
         }
         
         function getItemsWorker(nodes: Node[], createItem: (n: Node) => ts.NavigationBarItem): ts.NavigationBarItem[] {
-            var items: ts.NavigationBarItem[] = [];
+            let items: ts.NavigationBarItem[] = [];
 
-            var keyToItem: Map<NavigationBarItem> = {};
+            let keyToItem: Map<NavigationBarItem> = {};
 
-            for (var i = 0, n = nodes.length; i < n; i++) {
-                var child = nodes[i];
-                var item = createItem(child);
+            for (let child of nodes) {
+                let item = createItem(child);
                 if (item !== undefined) {
                     if (item.text.length > 0) {
-                        var key = item.text + "-" + item.kind + "-" + item.indent;
+                        let key = item.text + "-" + item.kind + "-" + item.indent;
 
-                        var itemWithSameName = keyToItem[key];
+                        let itemWithSameName = keyToItem[key];
                         if (itemWithSameName) {
                             // We had an item with the same name.  Merge these items together.
                             merge(itemWithSameName, item);
@@ -169,7 +228,7 @@ module ts.NavigationBar {
 
         function merge(target: ts.NavigationBarItem, source: ts.NavigationBarItem) {
             // First, add any spans in the source to the target.
-            target.spans.push.apply(target.spans, source.spans);
+            addRange(target.spans, source.spans);
 
             if (source.childItems) {
                 if (!target.childItems) {
@@ -178,12 +237,8 @@ module ts.NavigationBar {
 
                 // Next, recursively merge or add any children in the source as appropriate.
                 outer:
-                for (var i = 0, n = source.childItems.length; i < n; i++) {
-                    var sourceChild = source.childItems[i];
-
-                    for (var j = 0, m = target.childItems.length; j < m; j++) {
-                        var targetChild = target.childItems[j];
-
+                for (let sourceChild of source.childItems) {
+                    for (let targetChild of target.childItems) {
                         if (targetChild.text === sourceChild.text && targetChild.kind === sourceChild.kind) {
                             // Found a match.  merge them.
                             merge(targetChild, sourceChild);
@@ -200,12 +255,16 @@ module ts.NavigationBar {
         function createChildItem(node: Node): ts.NavigationBarItem {
             switch (node.kind) {
                 case SyntaxKind.Parameter:
+                    if (isBindingPattern((<ParameterDeclaration>node).name)) {
+                        break;
+                    }
                     if ((node.flags & NodeFlags.Modifier) === 0) {
                         return undefined;
                     }
                     return createItem(node, getTextOfNode((<ParameterDeclaration>node).name), ts.ScriptElementKind.memberVariableElement);
 
-                case SyntaxKind.Method:
+                case SyntaxKind.MethodDeclaration:
+                case SyntaxKind.MethodSignature:
                     return createItem(node, getTextOfNode((<MethodDeclaration>node).name), ts.ScriptElementKind.memberFunctionElement);
 
                 case SyntaxKind.GetAccessor:
@@ -226,25 +285,53 @@ module ts.NavigationBar {
                 case SyntaxKind.ConstructSignature:
                     return createItem(node, "new()", ts.ScriptElementKind.constructSignatureElement);
 
-                case SyntaxKind.Property:
+                case SyntaxKind.PropertyDeclaration:
+                case SyntaxKind.PropertySignature:
                     return createItem(node, getTextOfNode((<PropertyDeclaration>node).name), ts.ScriptElementKind.memberVariableElement);
 
                 case SyntaxKind.FunctionDeclaration:
                     return createItem(node, getTextOfNode((<FunctionLikeDeclaration>node).name), ts.ScriptElementKind.functionElement);
 
                 case SyntaxKind.VariableDeclaration:
-                    if (isConst(node)) {
-                        return createItem(node, getTextOfNode((<VariableDeclaration>node).name), ts.ScriptElementKind.constElement);
-                    }
-                    else if (isLet(node)) {
-                        return createItem(node, getTextOfNode((<VariableDeclaration>node).name), ts.ScriptElementKind.letElement);
+                case SyntaxKind.BindingElement:
+                    let variableDeclarationNode: Node;
+                    let name: Node;
+
+                    if (node.kind === SyntaxKind.BindingElement) {
+                        name = (<BindingElement>node).name;
+                        variableDeclarationNode = node;
+                        // binding elements are added only for variable declarations
+                        // bubble up to the containing variable declaration
+                        while (variableDeclarationNode && variableDeclarationNode.kind !== SyntaxKind.VariableDeclaration) {
+                            variableDeclarationNode = variableDeclarationNode.parent;
+                        }
+                        Debug.assert(variableDeclarationNode !== undefined);
                     }
                     else {
-                        return createItem(node, getTextOfNode((<VariableDeclaration>node).name), ts.ScriptElementKind.variableElement);
+                        Debug.assert(!isBindingPattern((<VariableDeclaration>node).name));
+                        variableDeclarationNode = node;
+                        name = (<VariableDeclaration>node).name;
                     }
-                
+
+                    if (isConst(variableDeclarationNode)) {
+                        return createItem(node, getTextOfNode(name), ts.ScriptElementKind.constElement);
+                    }
+                    else if (isLet(variableDeclarationNode)) {
+                        return createItem(node, getTextOfNode(name), ts.ScriptElementKind.letElement);
+                    }
+                    else {
+                        return createItem(node, getTextOfNode(name), ts.ScriptElementKind.variableElement);
+                    }
+
                 case SyntaxKind.Constructor:
                     return createItem(node, "constructor", ts.ScriptElementKind.constructorImplementationElement);
+
+                case SyntaxKind.ExportSpecifier:
+                case SyntaxKind.ImportSpecifier:
+                case SyntaxKind.ImportEqualsDeclaration:
+                case SyntaxKind.ImportClause:
+                case SyntaxKind.NamespaceImport:
+                    return createItem(node, getTextOfNode((<Declaration>node).name), ts.ScriptElementKind.alias);
             }
 
             return undefined;
@@ -305,7 +392,7 @@ module ts.NavigationBar {
                 }
 
                 // Otherwise, we need to aggregate each identifier to build up the qualified name.
-                var result: string[] = [];
+                let result: string[] = [];
 
                 result.push(moduleDeclaration.name.text);
                 
@@ -319,9 +406,9 @@ module ts.NavigationBar {
             }
 
             function createModuleItem(node: ModuleDeclaration): NavigationBarItem {
-                var moduleName = getModuleName(node);
+                let moduleName = getModuleName(node);
                 
-                var childItems = getItemsWorker(getChildNodes((<Block>getInnermostModule(node).body).statements), createChildItem);
+                let childItems = getItemsWorker(getChildNodes((<Block>getInnermostModule(node).body).statements), createChildItem);
 
                 return getNavigationBarItem(moduleName,
                     ts.ScriptElementKind.moduleElement,
@@ -332,10 +419,10 @@ module ts.NavigationBar {
             }
 
             function createFunctionItem(node: FunctionDeclaration) {
-                if (node.name && node.body && node.body.kind === SyntaxKind.Block) {
-                    var childItems = getItemsWorker(sortNodes((<Block>node.body).statements), createChildItem);
+                if (node.body && node.body.kind === SyntaxKind.Block) {
+                    let childItems = getItemsWorker(sortNodes((<Block>node.body).statements), createChildItem);
 
-                    return getNavigationBarItem(node.name.text,
+                    return getNavigationBarItem(!node.name ? "default": node.name.text ,
                         ts.ScriptElementKind.functionElement,
                         getNodeModifiers(node),
                         [getNodeSpan(node)],
@@ -347,16 +434,16 @@ module ts.NavigationBar {
             }
 
             function createSourceFileItem(node: SourceFile): ts.NavigationBarItem {
-                var childItems = getItemsWorker(getChildNodes(node.statements), createChildItem);
+                let childItems = getItemsWorker(getChildNodes(node.statements), createChildItem);
 
                 if (childItems === undefined || childItems.length === 0) {
                     return undefined;
                 }
 
                 hasGlobalNode = true;
-                var rootName = isExternalModule(node) ?
-                    "\"" + escapeString(getBaseFilename(removeFileExtension(normalizePath(node.filename)))) + "\"" :
-                    "<global>"
+                let rootName = isExternalModule(node)
+                    ? "\"" + escapeString(getBaseFileName(removeFileExtension(normalizePath(node.fileName)))) + "\""
+                    : "<global>"
 
                 return getNavigationBarItem(rootName,
                     ts.ScriptElementKind.moduleElement,
@@ -366,26 +453,28 @@ module ts.NavigationBar {
             }
 
             function createClassItem(node: ClassDeclaration): ts.NavigationBarItem {
-                var childItems: NavigationBarItem[];
+                let childItems: NavigationBarItem[];
 
                 if (node.members) {
-                    var constructor = <ConstructorDeclaration>forEach(node.members, member => {
+                    let constructor = <ConstructorDeclaration>forEach(node.members, member => {
                         return member.kind === SyntaxKind.Constructor && member;
                     });
 
                     // Add the constructor parameters in as children of the class (for property parameters).
-                    // Note that *all* parameters will be added to the nodes array, but parameters that
+                    // Note that *all non-binding pattern named* parameters will be added to the nodes array, but parameters that
                     // are not properties will be filtered out later by createChildItem.
-                    var nodes: Node[] = removeComputedProperties(node);
+                    let nodes: Node[] = removeDynamicallyNamedProperties(node);
                     if (constructor) {
-                        nodes.push.apply(nodes, constructor.parameters);
+                        addRange(nodes, filter(constructor.parameters, p => !isBindingPattern(p.name)));
                     }
 
-                    var childItems = getItemsWorker(sortNodes(nodes), createChildItem);
+                    childItems = getItemsWorker(sortNodes(nodes), createChildItem);
                 }
 
+                var nodeName = !node.name ? "default" : node.name.text;
+
                 return getNavigationBarItem(
-                    node.name.text,
+                    nodeName,
                     ts.ScriptElementKind.classElement,
                     getNodeModifiers(node),
                     [getNodeSpan(node)],
@@ -394,7 +483,7 @@ module ts.NavigationBar {
             }
 
             function createEnumItem(node: EnumDeclaration): ts.NavigationBarItem {
-                var childItems = getItemsWorker(sortNodes(removeComputedProperties(node)), createChildItem);
+                let childItems = getItemsWorker(sortNodes(removeComputedProperties(node)), createChildItem);
                 return getNavigationBarItem(
                     node.name.text,
                     ts.ScriptElementKind.enumElement,
@@ -405,7 +494,7 @@ module ts.NavigationBar {
             }
 
             function createIterfaceItem(node: InterfaceDeclaration): ts.NavigationBarItem {
-                var childItems = getItemsWorker(sortNodes(removeComputedProperties(node)), createChildItem);
+                let childItems = getItemsWorker(sortNodes(removeDynamicallyNamedProperties(node)), createChildItem);
                 return getNavigationBarItem(
                     node.name.text,
                     ts.ScriptElementKind.interfaceElement,
@@ -416,10 +505,17 @@ module ts.NavigationBar {
             }
         }
 
-        function removeComputedProperties(node: ClassDeclaration | InterfaceDeclaration | EnumDeclaration): Declaration[] {
+        function removeComputedProperties(node: EnumDeclaration): Declaration[] {
             return filter<Declaration>(node.members, member => member.name === undefined || member.name.kind !== SyntaxKind.ComputedPropertyName);
         }
 
+        /**
+         * Like removeComputedProperties, but retains the properties with well known symbol names
+         */
+        function removeDynamicallyNamedProperties(node: ClassDeclaration | InterfaceDeclaration): Declaration[]{
+            return filter<Declaration>(node.members, member => !hasDynamicName(member));
+        }
+
         function getInnermostModule(node: ModuleDeclaration): ModuleDeclaration {
             while (node.body.kind === SyntaxKind.ModuleDeclaration) {
                 node = <ModuleDeclaration>node.body;
@@ -430,8 +526,8 @@ module ts.NavigationBar {
 
         function getNodeSpan(node: Node) {
             return node.kind === SyntaxKind.SourceFile
-                ? TextSpan.fromBounds(node.getFullStart(), node.getEnd())
-                : TextSpan.fromBounds(node.getStart(), node.getEnd());
+                ? createTextSpanFromBounds(node.getFullStart(), node.getEnd())
+                : createTextSpanFromBounds(node.getStart(), node.getEnd());
         }
 
         function getTextOfNode(node: Node): string {
