@@ -19,9 +19,7 @@ module clodule {
 var clodule = (function () {
     function clodule() {
     }
-    clodule.sfn = function (id) {
-        return 42;
-    };
+    clodule.sfn = function (id) { return 42; };
     return clodule;
 })();
 var clodule;
