@@ -8,7 +8,6 @@ class C {
 var C = (function () {
     function C() {
     }
-    C.prototype[1] = function () {
-    };
+    C.prototype[1] = function () { };
     return C;
 })();
