@@ -6,14 +6,14 @@ export class Model {
 }
 
 //// [aliasUsage1_moduleA.ts]
-import Backbone = require("aliasUsage1_backbone");
+import Backbone = require("./aliasUsage1_backbone");
 export class VisualizationModel extends Backbone.Model {
     // interesting stuff here
 }
 
 //// [aliasUsage1_main.ts]
-import Backbone = require("aliasUsage1_backbone");
-import moduleA = require("aliasUsage1_moduleA");
+import Backbone = require("./aliasUsage1_backbone");
+import moduleA = require("./aliasUsage1_moduleA");
 interface IHasVisualizationModel {
     VisualizationModel: typeof Backbone.Model;
 }
@@ -40,7 +40,7 @@ var __extends = (this && this.__extends) || function (d, b) {
     function __() { this.constructor = d; }
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
-var Backbone = require("aliasUsage1_backbone");
+var Backbone = require("./aliasUsage1_backbone");
 var VisualizationModel = (function (_super) {
     __extends(VisualizationModel, _super);
     function VisualizationModel() {
@@ -50,7 +50,7 @@ var VisualizationModel = (function (_super) {
 })(Backbone.Model);
 exports.VisualizationModel = VisualizationModel;
 //// [aliasUsage1_main.js]
-var moduleA = require("aliasUsage1_moduleA");
+var moduleA = require("./aliasUsage1_moduleA");
 var C2 = (function () {
     function C2() {
     }
