@@ -6,14 +6,14 @@ export class Model {
 }
 
 //// [aliasUsageInArray_moduleA.ts]
-import Backbone = require("aliasUsageInArray_backbone");
+import Backbone = require("./aliasUsageInArray_backbone");
 export class VisualizationModel extends Backbone.Model {
     // interesting stuff here
 }
 
 //// [aliasUsageInArray_main.ts]
-import Backbone = require("aliasUsageInArray_backbone");
-import moduleA = require("aliasUsageInArray_moduleA");
+import Backbone = require("./aliasUsageInArray_backbone");
+import moduleA = require("./aliasUsageInArray_moduleA");
 interface IHasVisualizationModel {
     VisualizationModel: typeof Backbone.Model;
 }
@@ -34,7 +34,7 @@ var __extends = (this && this.__extends) || function (d, b) {
     function __() { this.constructor = d; }
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
-var Backbone = require("aliasUsageInArray_backbone");
+var Backbone = require("./aliasUsageInArray_backbone");
 var VisualizationModel = (function (_super) {
     __extends(VisualizationModel, _super);
     function VisualizationModel() {
@@ -44,6 +44,6 @@ var VisualizationModel = (function (_super) {
 })(Backbone.Model);
 exports.VisualizationModel = VisualizationModel;
 //// [aliasUsageInArray_main.js]
-var moduleA = require("aliasUsageInArray_moduleA");
+var moduleA = require("./aliasUsageInArray_moduleA");
 var xs = [moduleA];
 var xs2 = [moduleA];
