@@ -6,14 +6,14 @@ export class Model {
 }
 
 //// [aliasUsageInFunctionExpression_moduleA.ts]
-import Backbone = require("aliasUsageInFunctionExpression_backbone");
+import Backbone = require("./aliasUsageInFunctionExpression_backbone");
 export class VisualizationModel extends Backbone.Model {
     // interesting stuff here
 }
 
 //// [aliasUsageInFunctionExpression_main.ts]
-import Backbone = require("aliasUsageInFunctionExpression_backbone");
-import moduleA = require("aliasUsageInFunctionExpression_moduleA");
+import Backbone = require("./aliasUsageInFunctionExpression_backbone");
+import moduleA = require("./aliasUsageInFunctionExpression_moduleA");
 interface IHasVisualizationModel {
     VisualizationModel: typeof Backbone.Model;
 }
@@ -33,7 +33,7 @@ var __extends = (this && this.__extends) || function (d, b) {
     function __() { this.constructor = d; }
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
-var Backbone = require("aliasUsageInFunctionExpression_backbone");
+var Backbone = require("./aliasUsageInFunctionExpression_backbone");
 var VisualizationModel = (function (_super) {
     __extends(VisualizationModel, _super);
     function VisualizationModel() {
@@ -43,6 +43,6 @@ var VisualizationModel = (function (_super) {
 })(Backbone.Model);
 exports.VisualizationModel = VisualizationModel;
 //// [aliasUsageInFunctionExpression_main.js]
-var moduleA = require("aliasUsageInFunctionExpression_moduleA");
+var moduleA = require("./aliasUsageInFunctionExpression_moduleA");
 var f = function (x) { return x; };
 f = function (x) { return moduleA; };
