@@ -6,14 +6,14 @@ export class Model {
 }
 
 //// [aliasUsageInOrExpression_moduleA.ts]
-import Backbone = require("aliasUsageInOrExpression_backbone");
+import Backbone = require("./aliasUsageInOrExpression_backbone");
 export class VisualizationModel extends Backbone.Model {
     // interesting stuff here
 }
 
 //// [aliasUsageInOrExpression_main.ts]
-import Backbone = require("aliasUsageInOrExpression_backbone");
-import moduleA = require("aliasUsageInOrExpression_moduleA");
+import Backbone = require("./aliasUsageInOrExpression_backbone");
+import moduleA = require("./aliasUsageInOrExpression_moduleA");
 interface IHasVisualizationModel {
     VisualizationModel: typeof Backbone.Model;
 }
@@ -37,7 +37,7 @@ var __extends = (this && this.__extends) || function (d, b) {
     function __() { this.constructor = d; }
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
-var Backbone = require("aliasUsageInOrExpression_backbone");
+var Backbone = require("./aliasUsageInOrExpression_backbone");
 var VisualizationModel = (function (_super) {
     __extends(VisualizationModel, _super);
     function VisualizationModel() {
@@ -47,7 +47,7 @@ var VisualizationModel = (function (_super) {
 })(Backbone.Model);
 exports.VisualizationModel = VisualizationModel;
 //// [aliasUsageInOrExpression_main.js]
-var moduleA = require("aliasUsageInOrExpression_moduleA");
+var moduleA = require("./aliasUsageInOrExpression_moduleA");
 var i;
 var d1 = i || moduleA;
 var d2 = i || moduleA;
