@@ -7,7 +7,7 @@ interface c {
 export = c;
 
 //// [aliasWithInterfaceExportAssignmentUsedInVarInitializer_1.ts]
-import moduleA = require("aliasWithInterfaceExportAssignmentUsedInVarInitializer_0");
+import moduleA = require("./aliasWithInterfaceExportAssignmentUsedInVarInitializer_0");
 var d = b.q3;
 
 //// [aliasWithInterfaceExportAssignmentUsedInVarInitializer_0.js]
