@@ -28,6 +28,4 @@ var M;
     M.C = C;
 })(M || (M = {}));
 var c = new M.C();
-c.m(function (n) {
-    return "hello: " + n;
-}, 18);
+c.m(function (n) { return "hello: " + n; }, 18);
