@@ -30,9 +30,7 @@ arr_any = c3; // should be an error - is
 var C3 = (function () {
     function C3() {
     }
-    C3.prototype.CM3M1 = function () {
-        return 3;
-    };
+    C3.prototype.CM3M1 = function () { return 3; };
     return C3;
 })();
 /*
@@ -49,7 +47,5 @@ Type 1 of any[]:
 var c3 = new C3();
 var o1 = { one: 1 };
 var arr_any = [];
-arr_any = function () {
-    return null;
-}; // should be an error - is
+arr_any = function () { return null; }; // should be an error - is
 arr_any = c3; // should be an error - is
