@@ -9,7 +9,7 @@ export = Car;
 
 //// [arrayOfExportedClass_1.ts]
 ///<reference path='arrayOfExportedClass_0.ts'/>
-import Car = require('arrayOfExportedClass_0');
+import Car = require('./arrayOfExportedClass_0');
 
 class Road {
 
