@@ -11,6 +11,4 @@ var C = (function () {
     }
     return C;
 })();
-var c = new C(function () {
-    return asdf;
-}); // should error
+var c = new C(function () { return asdf; }); // should error
