@@ -77,8 +77,8 @@ var E;
 (function (E) {
     E[E["A"] = 0] = "A";
 })(E || (E = {}));
-x = 0 /* A */;
-var f = 0 /* A */;
+x = E.A;
+var f = E.A;
 x = f;
 var g;
 x = g;
@@ -91,12 +91,8 @@ var h;
 x = h;
 var i;
 x = i;
-x = { f: function () {
-    return 1;
-} };
-x = { f: function (x) {
-    return x;
-} };
+x = { f: function () { return 1; } };
+x = { f: function (x) { return x; } };
 function j(a) {
     x = a;
 }
