@@ -13,8 +13,6 @@ module M {
 //// [assignToFn.js]
 var M;
 (function (M) {
-    var x = { f: function (n) {
-        return true;
-    } };
+    var x = { f: function (n) { return true; } };
     x.f = "hello";
 })(M || (M = {}));
