@@ -23,7 +23,6 @@ var v2: {
 
 //// [augmentedTypeAssignmentCompatIndexSignature.js]
 var o = {};
-var f = function () {
-};
+var f = function () { };
 var v1 = o; // Should be allowed
 var v2 = f; // Should be allowed
