@@ -18,15 +18,13 @@ class c5c { public foo() { } }
 var c5 = (function () {
     function c5() {
     }
-    c5.prototype.foo = function () {
-    };
+    c5.prototype.foo = function () { };
     return c5;
 })();
 var c5a = (function () {
     function c5a() {
     }
-    c5a.prototype.foo = function () {
-    };
+    c5a.prototype.foo = function () { };
     return c5a;
 })();
 var c5a;
@@ -36,8 +34,7 @@ var c5a;
 var c5b = (function () {
     function c5b() {
     }
-    c5b.prototype.foo = function () {
-    };
+    c5b.prototype.foo = function () { };
     return c5b;
 })();
 var c5b;
@@ -48,8 +45,7 @@ var c5b;
 var c5c = (function () {
     function c5c() {
     }
-    c5c.prototype.foo = function () {
-    };
+    c5c.prototype.foo = function () { };
     return c5c;
 })();
 //import c5c = require(''); 
