@@ -9,14 +9,12 @@ class c3 { public bar() { } } // error
 var c3 = (function () {
     function c3() {
     }
-    c3.prototype.foo = function () {
-    };
+    c3.prototype.foo = function () { };
     return c3;
 })(); // error
 var c3 = (function () {
     function c3() {
     }
-    c3.prototype.bar = function () {
-    };
+    c3.prototype.bar = function () { };
     return c3;
 })(); // error
