@@ -31,7 +31,7 @@ var e2;
 (function (e2) {
     e2[e2["One"] = 0] = "One";
 })(e2 || (e2 = {}));
-;
+; // error
 var e2 = (function () {
     function e2() {
     }
