@@ -9,8 +9,7 @@ define(["require", "exports"], function (require, exports) {
     var c5 = (function () {
         function c5() {
         }
-        c5.prototype.foo = function () {
-        };
+        c5.prototype.foo = function () { };
         return c5;
     })();
 });
