@@ -29,25 +29,21 @@ module m2g { export class C { foo() { } } }
 
 
 //// [augmentedTypesModules2.js]
-function m2() {
-}
-;
+function m2() { }
+; // ok since the module is not instantiated
 var m2a;
 (function (m2a) {
     var y = 2;
 })(m2a || (m2a = {}));
-function m2a() {
-}
-;
+function m2a() { }
+; // error since the module is instantiated
 var m2b;
 (function (m2b) {
     m2b.y = 2;
 })(m2b || (m2b = {}));
-function m2b() {
-}
-;
-function m2c() {
-}
+function m2b() { }
+; // error since the module is instantiated
+function m2c() { }
 ;
 var m2c;
 (function (m2c) {
@@ -57,22 +53,18 @@ var m2cc;
 (function (m2cc) {
     m2cc.y = 2;
 })(m2cc || (m2cc = {}));
-function m2cc() {
-}
+function m2cc() { }
+; // error to have module first
+function m2f() { }
 ;
-function m2f() {
-}
-;
-function m2g() {
-}
+function m2g() { }
 ;
 var m2g;
 (function (m2g) {
     var C = (function () {
         function C() {
         }
-        C.prototype.foo = function () {
-        };
+        C.prototype.foo = function () { };
         return C;
     })();
     m2g.C = C;
