@@ -19,7 +19,6 @@ var m3a;
 var m3a = (function () {
     function m3a() {
     }
-    m3a.prototype.foo = function () {
-    };
+    m3a.prototype.foo = function () { };
     return m3a;
 })(); // error, class isn't ambient or declared before the module
