@@ -51,8 +51,7 @@ var m4d;
     var C = (function () {
         function C() {
         }
-        C.prototype.foo = function () {
-        };
+        C.prototype.foo = function () { };
         return C;
     })();
 })(m4d || (m4d = {}));
