@@ -38,13 +38,9 @@ var r7 = i2.f(1);
 
 //// [callGenericFunctionWithZeroTypeArguments.js]
 // valid invocations of generic functions with no explicit type arguments provided 
-function f(x) {
-    return null;
-}
+function f(x) { return null; }
 var r = f(1);
-var f2 = function (x) {
-    return null;
-};
+var f2 = function (x) { return null; };
 var r2 = f2(1);
 var f3;
 var r3 = f3(1);
