@@ -22,13 +22,10 @@ var Foo = (function () {
     function Foo(x) {
         // WScript.Echo("Constructor function has executed");
     }
-    Foo.prototype.bar1 = function () {
-    };
+    Foo.prototype.bar1 = function () { };
     return Foo;
 })();
-function F1(a) {
-    return a;
-}
+function F1(a) { return a; }
 var f1 = new Foo("hey");
 f1.bar1();
 Foo();
