@@ -30,16 +30,11 @@ var Foo = (function () {
     function Foo(x) {
         // WScript.Echo("Constructor function has executed");
     }
-    Foo.prototype.bar1 = function () {
-    };
+    Foo.prototype.bar1 = function () { };
     return Foo;
 })();
-function F1(s) {
-    return s;
-} // error
-function F1(a) {
-    return a;
-} // error
+function F1(s) { return s; } // error
+function F1(a) { return a; } // error
 var f1 = new Foo("hey");
 f1.bar1();
 Foo();
