@@ -24,8 +24,7 @@ var Foo = (function () {
     function Foo(x) {
         // WScript.Echo("Constructor function has executed");
     }
-    Foo.prototype.bar1 = function (a) {
-    };
+    Foo.prototype.bar1 = function (a) { };
     return Foo;
 })();
 //class Foo(s: String);
