@@ -9,11 +9,10 @@ class B extends A {
 }
 
 //// [captureThisInSuperCall.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function () {
     function A(p) {
@@ -26,7 +25,6 @@ var B = (function (_super) {
         var _this = this;
         _super.call(this, { test: function () { return _this.someMethod(); } });
     }
-    B.prototype.someMethod = function () {
-    };
+    B.prototype.someMethod = function () { };
     return B;
 })(A);
