@@ -7,6 +7,11 @@ declare var a;
 (<any>[1,3,]); 
 (<any>"string"); 
 (<any>23.0); 
+(<any>1); 
+(<any>1.);
+(<any>1.0);
+(<any>12e+34);
+(<any>0xff);
 (<any>/regexp/g); 
 (<any>false); 
 (<any>true); 
@@ -23,6 +28,12 @@ declare var a;
 declare var A;
 
 // should keep the parentheses in emit
+(<any>1).foo;
+(<any>1.).foo;
+(<any>1.0).foo;
+(<any>12e+34).foo;
+(<any>0xff).foo;
+(<any>(1.0)); 
 (<any>new A).foo; 
 (<any>typeof A).x; 
 (<any>-A).x; 
@@ -46,6 +57,11 @@ new (<any>A());
 [1, 3,];
 "string";
 23.0;
+1;
+1.;
+1.0;
+12e+34;
+0xff;
 /regexp/g;
 false;
 true;
@@ -59,6 +75,12 @@ a[0];
 a.b["0"];
 a().x;
 // should keep the parentheses in emit
+(1).foo;
+(1.).foo;
+(1.0).foo;
+(12e+34).foo;
+(0xff).foo;
+(1.0);
 (new A).foo;
 (typeof A).x;
 (-A).x;
