@@ -7,12 +7,8 @@ function f() {
 
 //// [catch.js]
 function f() {
-    try {
-    }
-    catch (e) {
-    }
-    try {
-    }
-    catch (e) {
-    }
+    try { }
+    catch (e) { }
+    try { }
+    catch (e) { }
 }
