@@ -7,7 +7,7 @@ c.c;
 
 
 //// [classExpressionES63.js]
-let C = class class_1 extends class class_2 extends class class_3 {
+let C = class extends class extends class {
     constructor() {
         this.a = 1;
     }
