@@ -14,11 +14,10 @@ module Foo {
 }
 
 //// [classExtendsClauseClassMergedWithModuleNotReferingConstructor.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function () {
     function A() {
@@ -27,7 +26,6 @@ var A = (function () {
 })();
 var A;
 (function (A) {
-    A.v;
 })(A || (A = {}));
 var Foo;
 (function (Foo) {
