@@ -6,14 +6,12 @@ var x = new foo(); // can be used as a constructor function
 class C extends foo { } // error, cannot extend it though
 
 //// [classExtendsValidConstructorFunction.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
-function foo() {
-}
+function foo() { }
 var x = new foo(); // can be used as a constructor function
 var C = (function (_super) {
     __extends(C, _super);
