@@ -7,7 +7,6 @@ class C {
 var C = (function () {
     function C() {
     }
-    C.try = function () {
-    };
+    C.try = function () { };
     return C;
 })();
