@@ -20,27 +20,23 @@ a.foo();
 
 
 //// [classOrder2.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function (_super) {
     __extends(A, _super);
     function A() {
         _super.apply(this, arguments);
     }
-    A.prototype.foo = function () {
-        this.bar();
-    };
+    A.prototype.foo = function () { this.bar(); };
     return A;
 })(B);
 var B = (function () {
     function B() {
     }
-    B.prototype.bar = function () {
-    };
+    B.prototype.bar = function () { };
     return B;
 })();
 var a = new A();
