@@ -30,8 +30,7 @@ var c;
 var o = c;
 c = 1;
 c = { foo: '' };
-c = function () {
-};
+c = function () { };
 var D = (function () {
     function D() {
         return 1;
@@ -42,5 +41,4 @@ var d;
 var o = d;
 d = 1;
 d = { foo: '' };
-d = function () {
-};
+d = function () { };
