@@ -30,15 +30,10 @@ i = c;
 var C = (function () {
     function C() {
     }
-    C.prototype.y = function (a) {
-        return null;
-    };
+    C.prototype.y = function (a) { return null; };
     Object.defineProperty(C.prototype, "z", {
-        get: function () {
-            return 1;
-        },
-        set: function (v) {
-        },
+        get: function () { return 1; },
+        set: function (v) { },
         enumerable: true,
         configurable: true
     });
