@@ -9,7 +9,6 @@ class C {
 var C = (function () {
     function C() {
     }
-    C.prototype.bar = function (x) {
-    };
+    C.prototype.bar = function (x) { };
     return C;
 })();
