@@ -23,11 +23,10 @@ module Path.Utils {
 
 
 //// [clodulesDerivedClasses.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Shape = (function () {
     function Shape() {
@@ -38,9 +37,7 @@ var Shape;
 (function (Shape) {
     var Utils;
     (function (Utils) {
-        function convert() {
-            return null;
-        }
+        function convert() { return null; }
         Utils.convert = convert;
     })(Utils = Shape.Utils || (Shape.Utils = {}));
 })(Shape || (Shape = {}));
