@@ -12,6 +12,6 @@ var m1;
     var e;
     (function (e) {
         e[e["m1"] = 0] = "m1";
-        e[e["m2"] = e.m1] = "m2";
+        e[e["m2"] = 0] = "m2";
     })(e || (e = {}));
 })(m1 || (m1 = {}));
