@@ -31,13 +31,13 @@ var foo2 = new m2.m2();
 
 //// [collisionCodeGenModuleWithModuleReopening.js]
 var m1;
-(function (_m1) {
+(function (m1_1) {
     var m1 = (function () {
         function m1() {
         }
         return m1;
     })();
-    _m1.m1 = m1;
+    m1_1.m1 = m1;
 })(m1 || (m1 = {}));
 var foo = new m1.m1();
 var m1;
@@ -65,16 +65,16 @@ var m2;
 })(m2 || (m2 = {}));
 var foo3 = new m2.c1();
 var m2;
-(function (_m2) {
+(function (m2_1) {
     var m2 = (function () {
         function m2() {
         }
         return m2;
     })();
-    _m2.m2 = m2;
+    m2_1.m2 = m2;
     var b = new m2();
-    var d = _m2.b10;
-    var c = new _m2.c1();
+    var d = m2_1.b10;
+    var c = new m2_1.c1();
 })(m2 || (m2 = {}));
 var foo3 = new m2.c1();
 var foo2 = new m2.m2();
