@@ -21,11 +21,10 @@ class c extends Foo {
 }
 
 //// [collisionSuperAndLocalVarInConstructor.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var _super = 10; // No Error
 var Foo = (function () {
