@@ -1,7 +1,12 @@
 //// [tests/cases/compiler/commentOnAmbientClass1.ts] ////
 
 //// [a.ts]
-/*! Keep this pinned comment */
+/*!=========
+    Keep this pinned comment
+   =========
+*/
+
+/*! Don't keep this pinned comment */
 declare class C {
 }
 
@@ -15,6 +20,9 @@ declare class E extends C {
 }
 
 //// [a.js]
-/*! Keep this pinned comment */
+/*!=========
+    Keep this pinned comment
+   =========
+*/
 //// [b.js]
 ///<reference path="a.ts"/>
