@@ -5,6 +5,4 @@ export var b: number;
 
 //// [commentsBeforeVariableStatement1.js]
 define(["require", "exports"], function (require, exports) {
-    /** b's comment*/
-    exports.b;
 });
