@@ -54,7 +54,7 @@ var myvar2 = new m4.m2.c();
 
 //// [commentsExternalModules_1.ts]
 /**This is on import declaration*/
-import extMod = require("commentsExternalModules2_0"); // trailing comment 1
+import extMod = require("./commentsExternalModules2_0"); // trailing comment 1
 extMod.m1.fooExport();
 export var newVar = new extMod.m1.m2.c();
 extMod.m4.fooExport();
@@ -124,7 +124,7 @@ m4.fooExport();
 var myvar2 = new m4.m2.c();
 //// [commentsExternalModules_1.js]
 /**This is on import declaration*/
-var extMod = require("commentsExternalModules2_0"); // trailing comment 1
+var extMod = require("./commentsExternalModules2_0"); // trailing comment 1
 extMod.m1.fooExport();
 exports.newVar = new extMod.m1.m2.c();
 extMod.m4.fooExport();
@@ -165,6 +165,6 @@ export declare module m4 {
 }
 //// [commentsExternalModules_1.d.ts]
 /**This is on import declaration*/
-import extMod = require("commentsExternalModules2_0");
+import extMod = require("./commentsExternalModules2_0");
 export declare var newVar: extMod.m1.m2.c;
 export declare var newVar2: extMod.m4.m2.c;
