@@ -27,8 +27,7 @@ var v = {
     func: function () {
     },
     //PropertyName + CallSignature
-    func1: function () {
-    },
+    func1: function () { },
     //getter
     get a() {
         return this.prop;
