@@ -20,18 +20,16 @@ class Container {
 }
 
 //// [constraintCheckInGenericBaseTypeReference.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 // No errors
 var Constraint = (function () {
     function Constraint() {
     }
-    Constraint.prototype.method = function () {
-    };
+    Constraint.prototype.method = function () { };
     return Constraint;
 })();
 var GenericBase = (function () {
