@@ -40,8 +40,7 @@ var i2: I2<{}>;
 //// [constraintSatisfactionWithEmptyObject.js]
 // valid uses of a basic object constraint, no errors expected
 // Object constraint
-function foo(x) {
-}
+function foo(x) { }
 var r = foo({});
 var a = {};
 var r = foo({});
@@ -54,8 +53,7 @@ var C = (function () {
 var r2 = new C({});
 var i;
 // {} constraint
-function foo2(x) {
-}
+function foo2(x) { }
 var r = foo2({});
 var a = {};
 var r = foo2({});
