@@ -23,8 +23,7 @@ var Test;
         return MyClass;
     })();
     Test.MyClass = MyClass;
-    function F(func) {
-    }
+    function F(func) { }
     Test.F = F;
 })(Test || (Test = {}));
 var func;
