@@ -34,11 +34,10 @@ class Derived2 extends Base {
 
 //// [constructorFunctionTypeIsAssignableToBaseType2.js]
 // the constructor function itself does not need to be a subtype of the base type constructor function
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Base = (function () {
     function Base(x) {
