@@ -26,17 +26,15 @@ f1.bar1();
 
 
 //// [constructorOverloads2.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var FooBase = (function () {
     function FooBase(x) {
     }
-    FooBase.prototype.bar1 = function () {
-    };
+    FooBase.prototype.bar1 = function () { };
     return FooBase;
 })();
 var Foo = (function (_super) {
@@ -44,8 +42,7 @@ var Foo = (function (_super) {
     function Foo(x, y) {
         _super.call(this, x);
     }
-    Foo.prototype.bar1 = function () {
-    };
+    Foo.prototype.bar1 = function () { };
     return Foo;
 })(FooBase);
 var f1 = new Foo("hey");
