@@ -14,8 +14,7 @@ var X = (function () {
     function X() {
         return 1;
     }
-    X.prototype.foo = function () {
-    };
+    X.prototype.foo = function () { };
     return X;
 })();
 var x = new X();
