@@ -2,7 +2,6 @@
 function foo(param:{id:number;}){}; foo(<{id:number;}>({}));
 
 //// [contextualTyping25.js]
-function foo(param) {
-}
+function foo(param) { }
 ;
 foo(({}));
