@@ -2,7 +2,6 @@
 function foo(param:number[]){}; foo([1, "a"]);
 
 //// [contextualTyping30.js]
-function foo(param) {
-}
+function foo(param) { }
 ;
 foo([1, "a"]);
