@@ -2,6 +2,4 @@
 var foo = <{ (): number; }> function() { return "err"; };
 
 //// [contextualTyping39.js]
-var foo = function () {
-    return "err";
-};
+var foo = function () { return "err"; };
