@@ -15,11 +15,10 @@ var xs = [(x: A) => { }, (x: B) => { }, (x: C) => { }];
 
 
 //// [contextualTypingArrayOfLambdas.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function () {
     function A() {
@@ -40,7 +39,4 @@ var C = (function (_super) {
     }
     return C;
 })(A);
-var xs = [function (x) {
-}, function (x) {
-}, function (x) {
-}];
+var xs = [function (x) { }, function (x) { }, function (x) { }];
