@@ -15,11 +15,10 @@ var x2: (a: A) => void = true ? (a) => a.foo : (b) => b.foo;
 
 
 //// [contextualTypingOfConditionalExpression.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var x = true ? function (a) { return a.toExponential(); } : function (b) { return b.toFixed(); };
 var A = (function () {
