@@ -6,7 +6,7 @@ export class Foo { }
 
 //// [declFileAliasUseBeforeDeclaration_test.ts]
 export function bar(a: foo.Foo) { }
-import foo = require("declFileAliasUseBeforeDeclaration_foo");
+import foo = require("./declFileAliasUseBeforeDeclaration_foo");
 
 //// [declFileAliasUseBeforeDeclaration_foo.js]
 var Foo = (function () {
@@ -25,4 +25,4 @@ export declare class Foo {
 }
 //// [declFileAliasUseBeforeDeclaration_test.d.ts]
 export declare function bar(a: foo.Foo): void;
-import foo = require("declFileAliasUseBeforeDeclaration_foo");
+import foo = require("./declFileAliasUseBeforeDeclaration_foo");
