@@ -31,28 +31,22 @@ interface I extends A, B {
 var A = (function () {
     function A() {
     }
-    A.prototype.foo = function () {
-    };
+    A.prototype.foo = function () { };
     return A;
 })();
 var B = (function () {
     function B() {
     }
-    B.prototype.bar = function () {
-    };
+    B.prototype.bar = function () { };
     return B;
 })();
 var D = (function () {
     function D() {
     }
-    D.prototype.baz = function () {
-    };
-    D.prototype.bat = function () {
-    };
-    D.prototype.foo = function () {
-    };
-    D.prototype.bar = function () {
-    };
+    D.prototype.baz = function () { };
+    D.prototype.bat = function () { };
+    D.prototype.foo = function () { };
+    D.prototype.bar = function () { };
     return D;
 })();
 
