@@ -10,8 +10,7 @@ class C {
 var C = (function () {
     function C() {
     }
-    C.prototype.foo = function (x) {
-    };
+    C.prototype.foo = function (x) { };
     return C;
 })();
 
