@@ -17,17 +17,11 @@ function f1() {
         args[_i - 0] = arguments[_i];
     }
 }
-function f2(x) {
-}
-function f3(x) {
-}
-function f4() {
-}
-function f5() {
-}
-var f6 = function () {
-    return [10];
-};
+function f2(x) { }
+function f3(x) { }
+function f4() { }
+function f5() { }
+var f6 = function () { return [10]; };
 
 
 //// [declFileRestParametersOfFunctionAndFunctionType.d.ts]
