@@ -38,22 +38,12 @@ var M;
     var D = (function () {
         function D() {
         }
-        D.prototype.m232 = function () {
-            return null;
-        };
-        D.prototype.m242 = function () {
-            return null;
-        };
-        D.prototype.m252 = function () {
-            return null;
-        }; // don't generate
-        D.prototype.m26 = function (i) {
-        };
-        D.prototype.m262 = function (i) {
-        };
-        D.prototype.m3 = function () {
-            return new C();
-        };
+        D.prototype.m232 = function () { return null; };
+        D.prototype.m242 = function () { return null; };
+        D.prototype.m252 = function () { return null; }; // don't generate
+        D.prototype.m26 = function (i) { };
+        D.prototype.m262 = function (i) { };
+        D.prototype.m3 = function () { return new C(); };
         return D;
     })();
     M.D = D;
