@@ -7,7 +7,7 @@ export function bar() { }
 export interface Buzz { }
 
 //// [index.ts]
-import {foo} from "utils";
+import {foo} from "./utils";
 export = foo;
 
 //// [utils.js]
@@ -16,7 +16,7 @@ exports.foo = foo;
 function bar() { }
 exports.bar = bar;
 //// [index.js]
-var utils_1 = require("utils");
+var utils_1 = require("./utils");
 module.exports = utils_1.foo;
 
 
@@ -26,5 +26,5 @@ export declare function bar(): void;
 export interface Buzz {
 }
 //// [index.d.ts]
-import { foo } from "utils";
+import { foo } from "./utils";
 export = foo;
