@@ -5,7 +5,7 @@ module f { export class c { } }
 export = f;
 
 //// [declarationEmit_nameConflicts_0.ts]
-import im = require('declarationEmit_nameConflicts_1');
+import im = require('./declarationEmit_nameConflicts_1');
 export module M {
     export function f() { }
     export class C { }
@@ -61,7 +61,7 @@ var f;
 })(f || (f = {}));
 module.exports = f;
 //// [declarationEmit_nameConflicts_0.js]
-var im = require('declarationEmit_nameConflicts_1');
+var im = require('./declarationEmit_nameConflicts_1');
 var M;
 (function (M) {
     function f() { }
@@ -138,7 +138,7 @@ declare module f {
 }
 export = f;
 //// [declarationEmit_nameConflicts_0.d.ts]
-import im = require('declarationEmit_nameConflicts_1');
+import im = require('./declarationEmit_nameConflicts_1');
 export declare module M {
     function f(): void;
     class C {
