@@ -20,12 +20,11 @@ var MyClass = (function () {
     }
     MyClass.prototype.doSomething = function () {
     };
-    Object.defineProperty(MyClass.prototype, "doSomething",
-        __decorate([
-            decorator, 
-            __metadata('design:type', Function), 
-            __metadata('design:paramtypes', []), 
-            __metadata('design:returntype', void 0)
-        ], MyClass.prototype, "doSomething", Object.getOwnPropertyDescriptor(MyClass.prototype, "doSomething")));
+    __decorate([
+        decorator, 
+        __metadata('design:type', Function), 
+        __metadata('design:paramtypes', []), 
+        __metadata('design:returntype', void 0)
+    ], MyClass.prototype, "doSomething", null);
     return MyClass;
 })();
