@@ -33,7 +33,7 @@ var B = (function () {
     __decorate([
         decorator, 
         __metadata('design:type', Object)
-    ], B.prototype, "x");
+    ], B.prototype, "x", void 0);
     return B;
 })();
 exports.B = B;
