@@ -22,17 +22,15 @@ var r2 = e.foo(1, '');
 
 //// [derivedClassTransitivity2.js]
 // subclassing is not transitive when you can remove required parameters and add optional parameters
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C = (function () {
     function C() {
     }
-    C.prototype.foo = function (x, y) {
-    };
+    C.prototype.foo = function (x, y) { };
     return C;
 })();
 var D = (function (_super) {
@@ -40,8 +38,7 @@ var D = (function (_super) {
     function D() {
         _super.apply(this, arguments);
     }
-    D.prototype.foo = function (x) {
-    }; // ok to drop parameters
+    D.prototype.foo = function (x) { }; // ok to drop parameters
     return D;
 })(C);
 var E = (function (_super) {
@@ -49,8 +46,7 @@ var E = (function (_super) {
     function E() {
         _super.apply(this, arguments);
     }
-    E.prototype.foo = function (x, y) {
-    }; // ok to add optional parameters
+    E.prototype.foo = function (x, y) { }; // ok to add optional parameters
     return E;
 })(D);
 var c;
