@@ -66,7 +66,6 @@ SEVEN: do
     while (true);
 while (true);
 EIGHT: do {
-    var fn = function () {
-    };
+    var fn = function () { };
     continue EIGHT;
 } while (true);
