@@ -29,8 +29,7 @@ function _setBarAndText(): void {
 var Base = (function () {
     function Base() {
     }
-    Base.prototype.foo = function () {
-    };
+    Base.prototype.foo = function () { };
     return Base;
 })();
 function each(collection, callback) {
