@@ -2,10 +2,10 @@
 
 //// [elidingImportNames_test.ts]
 
-import a = require('elidingImportNames_main'); // alias used in typeof
+import a = require('./elidingImportNames_main'); // alias used in typeof
 var b = a;
 var x: typeof a;
-import a2 = require('elidingImportNames_main1'); // alias not used in typeof
+import a2 = require('./elidingImportNames_main1'); // alias not used in typeof
 var b2 = a2;
 
 
@@ -20,8 +20,8 @@ exports.main = 10;
 //// [elidingImportNames_main1.js]
 exports.main = 10;
 //// [elidingImportNames_test.js]
-var a = require('elidingImportNames_main'); // alias used in typeof
+var a = require('./elidingImportNames_main'); // alias used in typeof
 var b = a;
 var x;
-var a2 = require('elidingImportNames_main1'); // alias not used in typeof
+var a2 = require('./elidingImportNames_main1'); // alias not used in typeof
 var b2 = a2;
