@@ -12,11 +12,10 @@ class derived extends base { }
 
 //// [errorForwardReferenceForwadingConstructor.js]
 // Error forward referencing derived class with forwarding constructor
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 function f() {
     var d1 = new derived();
