@@ -12,9 +12,7 @@ baz.concat("y");
 var Foo = (function () {
     function Foo() {
     }
-    Foo.bar = function () {
-        return "x";
-    };
+    Foo.bar = function () { return "x"; };
     return Foo;
 })();
 var baz = Foo.b;
