@@ -5,7 +5,7 @@
 export class a { }
 
 //// [client.ts]
-import defaultBinding, * as nameSpaceBinding  from "server";
+import defaultBinding, * as nameSpaceBinding  from "./server";
 export var x = new nameSpaceBinding.a();
 
 //// [server.js]
@@ -16,7 +16,7 @@ var a = (function () {
 })();
 exports.a = a;
 //// [client.js]
-var server_1 = require("server"), nameSpaceBinding = server_1;
+var server_1 = require("./server"), nameSpaceBinding = server_1;
 exports.x = new nameSpaceBinding.a();
 
 
@@ -24,5 +24,5 @@ exports.x = new nameSpaceBinding.a();
 export declare class a {
 }
 //// [client.d.ts]
-import * as nameSpaceBinding from "server";
+import * as nameSpaceBinding from "./server";
 export declare var x: nameSpaceBinding.a;
