@@ -6,7 +6,7 @@ var a = 10;
 export = a;
 
 //// [es6ImportDefaultBindingInEs5_1.ts]
-import defaultBinding from "es6ImportDefaultBindingInEs5_0";
+import defaultBinding from "./es6ImportDefaultBindingInEs5_0";
 
 //// [es6ImportDefaultBindingInEs5_0.js]
 var a = 10;
