@@ -5,7 +5,7 @@
 export var a = 10;
 
 //// [es6ImportDefaultBindingNoDefaultProperty_1.ts]
-import defaultBinding from "es6ImportDefaultBindingNoDefaultProperty_0";
+import defaultBinding from "./es6ImportDefaultBindingNoDefaultProperty_0";
 
 
 //// [es6ImportDefaultBindingNoDefaultProperty_0.js]
