@@ -5,15 +5,15 @@
 export var a = 10;
 
 //// [es6ImportNameSpaceImport_1.ts]
-import * as nameSpaceBinding from "es6ImportNameSpaceImport_0";
+import * as nameSpaceBinding from "./es6ImportNameSpaceImport_0";
 var x = nameSpaceBinding.a;
-import * as nameSpaceBinding2 from "es6ImportNameSpaceImport_0"; // elide this
+import * as nameSpaceBinding2 from "./es6ImportNameSpaceImport_0"; // elide this
 
 
 //// [es6ImportNameSpaceImport_0.js]
-export var a = 10;
+exports.a = 10;
 //// [es6ImportNameSpaceImport_1.js]
-import * as nameSpaceBinding from "es6ImportNameSpaceImport_0";
+var nameSpaceBinding = require("./es6ImportNameSpaceImport_0");
 var x = nameSpaceBinding.a;
 
 
