@@ -5,15 +5,15 @@
 export var a = 10;  
 
 //// [es6ImportNameSpaceImportInEs5_1.ts]
-import * as nameSpaceBinding from "es6ImportNameSpaceImportInEs5_0";
+import * as nameSpaceBinding from "./es6ImportNameSpaceImportInEs5_0";
 var x = nameSpaceBinding.a;
-import * as nameSpaceBinding2 from "es6ImportNameSpaceImportInEs5_0"; // elide this
+import * as nameSpaceBinding2 from "./es6ImportNameSpaceImportInEs5_0"; // elide this
 
 
 //// [es6ImportNameSpaceImportInEs5_0.js]
 exports.a = 10;
 //// [es6ImportNameSpaceImportInEs5_1.js]
-var nameSpaceBinding = require("es6ImportNameSpaceImportInEs5_0");
+var nameSpaceBinding = require("./es6ImportNameSpaceImportInEs5_0");
 var x = nameSpaceBinding.a;
 
 
