@@ -5,13 +5,13 @@
 export var a = 10;
 
 //// [es6ImportNameSpaceImportMergeErrors_1.ts]
-import * as nameSpaceBinding from "es6ImportNameSpaceImportMergeErrors_0"; 
+import * as nameSpaceBinding from "./es6ImportNameSpaceImportMergeErrors_0"; 
 interface nameSpaceBinding { } // this should be ok
 
-import * as nameSpaceBinding1 from "es6ImportNameSpaceImportMergeErrors_0"; // should be error
-import * as nameSpaceBinding1 from "es6ImportNameSpaceImportMergeErrors_0"; // should be error
+import * as nameSpaceBinding1 from "./es6ImportNameSpaceImportMergeErrors_0"; // should be error
+import * as nameSpaceBinding1 from "./es6ImportNameSpaceImportMergeErrors_0"; // should be error
 
-import * as nameSpaceBinding3 from "es6ImportNameSpaceImportMergeErrors_0"; // should be error
+import * as nameSpaceBinding3 from "./es6ImportNameSpaceImportMergeErrors_0"; // should be error
 var nameSpaceBinding3 = 10;
 
 
