@@ -6,7 +6,7 @@ var a = 10;
 export = a;
 
 //// [es6ImportNameSpaceImportNoNamedExports_1.ts]
-import * as nameSpaceBinding from "es6ImportNameSpaceImportNoNamedExports_0"; // error
+import * as nameSpaceBinding from "./es6ImportNameSpaceImportNoNamedExports_0"; // error
 
 //// [es6ImportNameSpaceImportNoNamedExports_0.js]
 var a = 10;
