@@ -30,8 +30,6 @@ var Foo = (function () {
 var Foo2 = (function () {
     function Foo2() {
     }
-    Foo2.Foo2 = function () {
-        return 0;
-    }; // should not be an error
+    Foo2.Foo2 = function () { return 0; }; // should not be an error
     return Foo2;
 })();
