@@ -12,10 +12,13 @@ export class A
 }
 
 //// [es6ModuleWithModuleGenTargetAmd.js]
-export class A {
-    constructor() {
+define(["require", "exports"], function (require, exports) {
+    class A {
+        constructor() {
+        }
+        B() {
+            return 42;
+        }
     }
-    B() {
-        return 42;
-    }
-}
+    exports.A = A;
+});
