@@ -12,7 +12,7 @@ export = Foo;
 
 //// [exportAssignClassAndModule_1.ts]
 ///<reference path='exportAssignClassAndModule_0.ts'/>
-import Foo = require('exportAssignClassAndModule_0');
+import Foo = require('./exportAssignClassAndModule_0');
 
 var z: Foo.Bar;
 var zz: Foo;
