@@ -6,7 +6,7 @@ var x = 0;
 export = x;
 
 //// [exportAssignmentVariable_B.ts]
-import y = require("exportAssignmentVariable_A");
+import y = require("./exportAssignmentVariable_A");
 
 var n: number = y;
 
@@ -14,5 +14,5 @@ var n: number = y;
 var x = 0;
 module.exports = x;
 //// [exportAssignmentVariable_B.js]
-var y = require("exportAssignmentVariable_A");
+var y = require("./exportAssignmentVariable_A");
 var n = y;
