@@ -17,7 +17,7 @@ export = server;
 
 //// [exportEqualMemberMissing_1.ts]
 ///<reference path='exportEqualMemberMissing_0.ts'/>
-import connect = require('exportEqualMemberMissing_0');
+import connect = require('./exportEqualMemberMissing_0');
 connect().use(connect.static('foo')); // Error	1	The property 'static' does not exist on value of type ''.
 
 
@@ -26,5 +26,5 @@ var server;
 module.exports = server;
 //// [exportEqualMemberMissing_1.js]
 ///<reference path='exportEqualMemberMissing_0.ts'/>
-var connect = require('exportEqualMemberMissing_0');
+var connect = require('./exportEqualMemberMissing_0');
 connect().use(connect.static('foo')); // Error	1	The property 'static' does not exist on value of type ''.
