@@ -14,17 +14,15 @@ d.baz();
 d.foo;
 
 //// [extendAndImplementTheSameBaseType.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C = (function () {
     function C() {
     }
-    C.prototype.bar = function () {
-    };
+    C.prototype.bar = function () { };
     return C;
 })();
 var D = (function (_super) {
@@ -32,8 +30,7 @@ var D = (function (_super) {
     function D() {
         _super.apply(this, arguments);
     }
-    D.prototype.baz = function () {
-    };
+    D.prototype.baz = function () { };
     return D;
 })(C);
 var c;
