@@ -17,11 +17,10 @@ var r3: string = d.bar();
 var r4: number = d.bar();
 
 //// [extendAndImplementTheSameBaseType2.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C = (function () {
     function C() {
@@ -36,8 +35,7 @@ var D = (function (_super) {
     function D() {
         _super.apply(this, arguments);
     }
-    D.prototype.baz = function () {
-    };
+    D.prototype.baz = function () { };
     return D;
 })(C);
 var d = new D();
