@@ -4,11 +4,10 @@ class derived extends base { }
 class base { constructor (public n: number) { } }
 
 //// [extendBaseClassBeforeItsDeclared.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var derived = (function (_super) {
     __extends(derived, _super);
