@@ -4,17 +4,15 @@ var x = A;
 class C extends x { } // error, could not find symbol xs
 
 //// [extendNonClassSymbol1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function () {
     function A() {
     }
-    A.prototype.foo = function () {
-    };
+    A.prototype.foo = function () { };
     return A;
 })();
 var x = A;
