@@ -6,11 +6,10 @@ var x = new Foo(); // legal, considered a constructor function
 class C extends Foo {} // error, could not find symbol Foo
 
 //// [extendNonClassSymbol2.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 function Foo() {
     this.x = 1;
