@@ -6,21 +6,21 @@ export class Model {
 }
 
 //// [extendingClassFromAliasAndUsageInIndexer_moduleA.ts]
-import Backbone = require("extendingClassFromAliasAndUsageInIndexer_backbone");
+import Backbone = require("./extendingClassFromAliasAndUsageInIndexer_backbone");
 export class VisualizationModel extends Backbone.Model {
     // interesting stuff here
 }
 
 //// [extendingClassFromAliasAndUsageInIndexer_moduleB.ts]
-import Backbone = require("extendingClassFromAliasAndUsageInIndexer_backbone");
+import Backbone = require("./extendingClassFromAliasAndUsageInIndexer_backbone");
 export class VisualizationModel extends Backbone.Model {
     // different interesting stuff here
 }
 
 //// [extendingClassFromAliasAndUsageInIndexer_main.ts]
-import Backbone = require("extendingClassFromAliasAndUsageInIndexer_backbone");
-import moduleA = require("extendingClassFromAliasAndUsageInIndexer_moduleA");
-import moduleB = require("extendingClassFromAliasAndUsageInIndexer_moduleB");
+import Backbone = require("./extendingClassFromAliasAndUsageInIndexer_backbone");
+import moduleA = require("./extendingClassFromAliasAndUsageInIndexer_moduleA");
+import moduleB = require("./extendingClassFromAliasAndUsageInIndexer_moduleB");
 interface IHasVisualizationModel {
     VisualizationModel: typeof Backbone.Model;
 }
@@ -45,7 +45,7 @@ var __extends = (this && this.__extends) || function (d, b) {
     function __() { this.constructor = d; }
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
-var Backbone = require("extendingClassFromAliasAndUsageInIndexer_backbone");
+var Backbone = require("./extendingClassFromAliasAndUsageInIndexer_backbone");
 var VisualizationModel = (function (_super) {
     __extends(VisualizationModel, _super);
     function VisualizationModel() {
@@ -60,7 +60,7 @@ var __extends = (this && this.__extends) || function (d, b) {
     function __() { this.constructor = d; }
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
-var Backbone = require("extendingClassFromAliasAndUsageInIndexer_backbone");
+var Backbone = require("./extendingClassFromAliasAndUsageInIndexer_backbone");
 var VisualizationModel = (function (_super) {
     __extends(VisualizationModel, _super);
     function VisualizationModel() {
@@ -70,8 +70,8 @@ var VisualizationModel = (function (_super) {
 })(Backbone.Model);
 exports.VisualizationModel = VisualizationModel;
 //// [extendingClassFromAliasAndUsageInIndexer_main.js]
-var moduleA = require("extendingClassFromAliasAndUsageInIndexer_moduleA");
-var moduleB = require("extendingClassFromAliasAndUsageInIndexer_moduleB");
+var moduleA = require("./extendingClassFromAliasAndUsageInIndexer_moduleA");
+var moduleB = require("./extendingClassFromAliasAndUsageInIndexer_moduleB");
 var moduleATyped = moduleA;
 var moduleMap = {
     "moduleA": moduleA,
