@@ -14,7 +14,7 @@ var E;
 (function (E) {
     E[E["x"] = 0] = "x";
 })(E || (E = {}));
-for ({ x, y:  = E.x } of array) {
+for ({ x, y = E.x } of array) {
     x;
     y;
 }
