@@ -20,12 +20,10 @@ module foo3 {
 class foo3 { } // Should error
 
 //// [funClodule.js]
-function foo3() {
-}
+function foo3() { }
 var foo3;
 (function (foo3) {
-    function x() {
-    }
+    function x() { }
     foo3.x = x;
 })(foo3 || (foo3 = {}));
 var foo3 = (function () {
