@@ -3,8 +3,6 @@ function foo():any{return ""};
 var x = foo();
 
 //// [functionCall1.js]
-function foo() {
-    return "";
-}
+function foo() { return ""; }
 ;
 var x = foo();
