@@ -13,8 +13,6 @@ var m1;
     })();
     m1.c1 = c1;
 })(m1 || (m1 = {}));
-function foo() {
-    return new m1.c1();
-}
+function foo() { return new m1.c1(); }
 ;
 var x = foo();
