@@ -6,7 +6,5 @@ var x = foo(5);
 
 
 //// [functionOverloads31.js]
-function foo(bar) {
-    return bar;
-}
+function foo(bar) { return bar; }
 var x = foo(5);
