@@ -3,6 +3,4 @@ function foo():number;
 function foo():string { return "a" }
 
 //// [functionOverloads4.js]
-function foo() {
-    return "a";
-}
+function foo() { return "a"; }
