@@ -9,7 +9,6 @@ class baz {
 var baz = (function () {
     function baz() {
     }
-    baz.prototype.foo = function (bar) {
-    };
+    baz.prototype.foo = function (bar) { };
     return baz;
 })();
