@@ -10,7 +10,6 @@ class foo {
 var foo = (function () {
     function foo() {
     }
-    foo.fnOverload = function (foo) {
-    };
+    foo.fnOverload = function (foo) { };
     return foo;
 })();
