@@ -14,8 +14,7 @@ module M {
 var C = (function () {
     function C() {
     }
-    C.foo = function (x) {
-    };
+    C.foo = function (x) { };
     return C;
 })();
 var M;
