@@ -23,9 +23,7 @@ var a4: I<string> = <K<number>>z;
 var A = (function () {
     function A() {
     }
-    A.prototype.compareTo = function (other) {
-        return 1;
-    };
+    A.prototype.compareTo = function (other) { return 1; };
     return A;
 })();
 var z = { x: new A() };
