@@ -16,11 +16,10 @@ class DataView2 extends BaseCollection2<CollectionItem2> {
 
 
 //// [genericBaseClassLiteralProperty2.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var CollectionItem2 = (function () {
     function CollectionItem2() {
