@@ -4,6 +4,5 @@ f<any>(null)
 
 
 //// [genericCallWithNonGenericArgs1.js]
-function f(x) {
-}
+function f(x) { }
 f(null);
