@@ -57,11 +57,8 @@ var r4 = foo(null, null);
 var r5 = foo({}, null);
 var r6 = foo(null, {});
 var r7 = foo({}, {});
-var r8 = foo(function () {
-}, function () {
-});
-var r9 = foo(function () {
-}, function () { return 1; });
+var r8 = foo(function () { }, function () { });
+var r9 = foo(function () { }, function () { return 1; });
 function other() {
     var r4 = foo(c, d);
     var r5 = foo(c, d); // error
