@@ -42,8 +42,7 @@ function foo(t, t2) {
 var c;
 var d;
 var r2 = foo(d, c); // the constraints are self-referencing, no downstream error
-var r9 = foo(function () { return 1; }, function () {
-}); // the constraints are self-referencing, no downstream error
+var r9 = foo(function () { return 1; }, function () { }); // the constraints are self-referencing, no downstream error
 function other() {
     var r5 = foo(c, d); // error
 }
