@@ -25,12 +25,9 @@ var Foo = (function () {
     Foo.f = function (xs) {
         return xs.reverse();
     };
-    Foo.a = function (n) {
-    };
+    Foo.a = function (n) { };
     Foo.c = [];
     Foo.d = false || (function (x) { return x || undefined; })(null);
-    Foo.e = function (x) {
-        return null;
-    };
+    Foo.e = function (x) { return null; };
     return Foo;
 })();
