@@ -18,10 +18,8 @@ var A;
     var B = (function () {
         function B() {
         }
-        B.prototype.foo = function () {
-        };
-        B.bar = function () {
-        };
+        B.prototype.foo = function () { };
+        B.bar = function () { };
         return B;
     })();
     A.B = B;
