@@ -6,7 +6,5 @@ function foo4<T>(test: string); // valid
 function foo4<T extends String>(test: T) { }
 
 //// [genericFunctionSpecializations1.js]
-function foo3(test) {
-}
-function foo4(test) {
-}
+function foo3(test) { }
+function foo4(test) { }
