@@ -37,26 +37,20 @@ var B = (function () {
 var X = (function () {
     function X() {
     }
-    X.prototype.f = function () {
-        return undefined;
-    };
+    X.prototype.f = function () { return undefined; };
     return X;
 })(); // { f: () => { b; } }
 // OK
 var Y = (function () {
     function Y() {
     }
-    Y.prototype.f = function () {
-        return undefined;
-    };
+    Y.prototype.f = function () { return undefined; };
     return Y;
 })(); // { f: () => { a; } }
 // OK
 var Z = (function () {
     function Z() {
     }
-    Z.prototype.f = function () {
-        return undefined;
-    };
+    Z.prototype.f = function () { return undefined; };
     return Z;
 })(); // { f: <T>() => T } 
