@@ -7,11 +7,8 @@ module foo {
 
 
 //// [genericMergedDeclarationUsingTypeParameter.js]
-function foo(y, z) {
-    return y;
-}
+function foo(y, z) { return y; }
 var foo;
 (function (foo) {
-    foo.x;
     var y = 1;
 })(foo || (foo = {}));
