@@ -16,9 +16,7 @@ var g2 = new G<M.C>() // was: error Type reference cannot refer to container 'M.
 var G = (function () {
     function G() {
     }
-    G.prototype.bar = function (x) {
-        return x;
-    };
+    G.prototype.bar = function (x) { return x; };
     return G;
 })();
 var M;
@@ -26,8 +24,7 @@ var M;
     var C = (function () {
         function C() {
         }
-        C.prototype.foo = function () {
-        };
+        C.prototype.foo = function () { };
         return C;
     })();
     M.C = C;
