@@ -19,9 +19,7 @@ module N {
 var G = (function () {
     function G() {
     }
-    G.prototype.bar = function (x) {
-        return x;
-    };
+    G.prototype.bar = function (x) { return x; };
     return G;
 })();
 var M;
@@ -29,8 +27,7 @@ var M;
     var C = (function () {
         function C() {
         }
-        C.prototype.foo = function () {
-        };
+        C.prototype.foo = function () { };
         return C;
     })();
     M.C = C;
