@@ -13,9 +13,7 @@ var r3 = r.foo(null);
 var C = (function () {
     function C() {
     }
-    C.prototype.foo = function (x) {
-        return null;
-    };
+    C.prototype.foo = function (x) { return null; };
     return C;
 })();
 var r = C.prototype;
