@@ -13,12 +13,8 @@ var r2b = i.get(1);
 var BiMap = (function () {
     function BiMap() {
     }
-    BiMap.prototype.get = function (key) {
-        return null;
-    };
-    BiMap.prototype.inverse = function () {
-        return null;
-    };
+    BiMap.prototype.get = function (key) { return null; };
+    BiMap.prototype.inverse = function () { return null; };
     return BiMap;
 })();
 var b = new BiMap();
