@@ -31,24 +31,18 @@ var IFoo = (function () {
 var IntFooBad = (function () {
     function IntFooBad() {
     }
-    IntFooBad.prototype.foo = function (x) {
-        return null;
-    };
+    IntFooBad.prototype.foo = function (x) { return null; };
     return IntFooBad;
 })();
 var StringFoo2 = (function () {
     function StringFoo2() {
     }
-    StringFoo2.prototype.foo = function (x) {
-        return null;
-    };
+    StringFoo2.prototype.foo = function (x) { return null; };
     return StringFoo2;
 })();
 var StringFoo3 = (function () {
     function StringFoo3() {
     }
-    StringFoo3.prototype.foo = function (x) {
-        return null;
-    };
+    StringFoo3.prototype.foo = function (x) { return null; };
     return StringFoo3;
 })();
