@@ -25,9 +25,7 @@ var A = (function () {
     A.one = function (source, value) {
         return source;
     };
-    A.goo = function () {
-        return 0;
-    };
+    A.goo = function () { return 0; };
     A.two = function (source) {
         return this.one(source, 42); // should not error
     };
