@@ -15,9 +15,7 @@ var i2: I<C>; // should be an error
 var C = (function () {
     function C() {
     }
-    C.prototype.foo = function () {
-        return null;
-    };
+    C.prototype.foo = function () { return null; };
     return C;
 })();
 var c1; // error
