@@ -14,23 +14,17 @@ f(g < A, B > +(7));
 var A = (function () {
     function A() {
     }
-    A.prototype.foo = function () {
-    };
+    A.prototype.foo = function () { };
     return A;
 })();
 var B = (function () {
     function B() {
     }
-    B.prototype.bar = function () {
-    };
+    B.prototype.bar = function () { };
     return B;
 })();
-function f(x) {
-    return x;
-}
-function g(x) {
-    return f(x);
-}
+function f(x) { return x; }
+function g(x) { return f(x); }
 g(7);
 f(g(7));
 f(g < A, B > 7);
