@@ -15,8 +15,7 @@ class arrTest {
 var arrTest = (function () {
     function arrTest() {
     }
-    arrTest.prototype.test = function (arg1) {
-    };
+    arrTest.prototype.test = function (arg1) { };
     arrTest.prototype.callTest = function () {
         this.test([1, 2, 3, 5]);
         this.test(["hi"]);
