@@ -15,7 +15,6 @@ var C = (function () {
     function C(c1, c2, c3) {
         this.x = null; // error at "x"
     } // error at "c1, c2"
-    C.prototype.funcOfC = function (f1, f2, f3) {
-    }; // error at "f1,f2"
+    C.prototype.funcOfC = function (f1, f2, f3) { }; // error at "f1,f2"
     return C;
 })();
