@@ -10,7 +10,5 @@ var r = c.compareTo(1, '');
 
 //// [implicitAnyGenericTypeInference.js]
 var c;
-c = { compareTo: function (x, y) {
-    return y;
-} };
+c = { compareTo: function (x, y) { return y; } };
 var r = c.compareTo(1, '');
