@@ -15,14 +15,12 @@ class C {
 
 
 //// [implicitAnyInCatch.js]
-try {
-}
+// this should not be an error
+try { }
 catch (error) {
-    if (error.number === -2147024809) {
-    }
-}
-for (var key in this) {
+    if (error.number === -2147024809) { }
 }
+for (var key in this) { }
 var C = (function () {
     function C() {
     }
