@@ -9,8 +9,8 @@ var x = '';
 
 //// [importAndVariableDeclarationConflict1.js]
 var m;
-(function (_m) {
-    _m.m = '';
+(function (m_1) {
+    m_1.m = '';
 })(m || (m = {}));
 var x = m.m;
 var x = '';
