@@ -9,8 +9,8 @@ import x = m.m;
 
 //// [importAndVariableDeclarationConflict4.js]
 var m;
-(function (_m) {
-    _m.m = '';
+(function (m_1) {
+    m_1.m = '';
 })(m || (m = {}));
 var x = '';
 var x = m.m;
