@@ -29,7 +29,7 @@ export var x: d;
 export function foo(): d { return null; }
 
 //// [importDecl_require4.ts]
-import m4 = require("importDecl_require");
+import m4 = require("./importDecl_require");
 export function foo2(): m4.d { return null; }
 
 //// [importDecl_1.ts]
@@ -38,7 +38,7 @@ export function foo2(): m4.d { return null; }
 ///<reference path='importDecl_require2.ts'/>
 ///<reference path='importDecl_require3.ts'/>
 ///<reference path='importDecl_require4.ts'/>
-import m4 = require("importDecl_require"); // Emit used
+import m4 = require("./importDecl_require"); // Emit used
 export var x4 = m4.x;
 export var d4 = m4.d;
 export var f4 = m4.foo();
@@ -54,16 +54,16 @@ export module m1 {
 }
 
 //Emit global only usage
-import glo_m4 = require("importDecl_require1");
+import glo_m4 = require("./importDecl_require1");
 export var useGlo_m4_d4 = glo_m4.d;
 export var useGlo_m4_f4 = glo_m4.foo();
 
 //Emit even when used just in function type
-import fncOnly_m4 = require("importDecl_require2");
+import fncOnly_m4 = require("./importDecl_require2");
 export var useFncOnly_m4_f4 = fncOnly_m4.foo();
 
 // only used privately no need to emit
-import private_m4 = require("importDecl_require3");
+import private_m4 = require("./importDecl_require3");
 export module usePrivate_m4_m1 {
     var x3 = private_m4.x;
     var d3 = private_m4.d;
@@ -71,11 +71,11 @@ export module usePrivate_m4_m1 {
 }
 
 // Do not emit unused import
-import m5 = require("importDecl_require4");
+import m5 = require("./importDecl_require4");
 export var d = m5.foo2();
 
 // Do not emit multiple used import statements
-import multiImport_m4 = require("importDecl_require"); // Emit used
+import multiImport_m4 = require("./importDecl_require"); // Emit used
 export var useMultiImport_m4_x4 = multiImport_m4.x;
 export var useMultiImport_m4_d4 = multiImport_m4.d;
 export var useMultiImport_m4_f4 = multiImport_m4.foo();
@@ -127,7 +127,7 @@ exports.foo2 = foo2;
 ///<reference path='importDecl_require2.ts'/>
 ///<reference path='importDecl_require3.ts'/>
 ///<reference path='importDecl_require4.ts'/>
-var m4 = require("importDecl_require"); // Emit used
+var m4 = require("./importDecl_require"); // Emit used
 exports.x4 = m4.x;
 exports.d4 = m4.d;
 exports.f4 = m4.foo();
@@ -141,14 +141,14 @@ var m1;
     var f3 = m4.foo();
 })(m1 = exports.m1 || (exports.m1 = {}));
 //Emit global only usage
-var glo_m4 = require("importDecl_require1");
+var glo_m4 = require("./importDecl_require1");
 exports.useGlo_m4_d4 = glo_m4.d;
 exports.useGlo_m4_f4 = glo_m4.foo();
 //Emit even when used just in function type
-var fncOnly_m4 = require("importDecl_require2");
+var fncOnly_m4 = require("./importDecl_require2");
 exports.useFncOnly_m4_f4 = fncOnly_m4.foo();
 // only used privately no need to emit
-var private_m4 = require("importDecl_require3");
+var private_m4 = require("./importDecl_require3");
 var usePrivate_m4_m1;
 (function (usePrivate_m4_m1) {
     var x3 = private_m4.x;
@@ -156,10 +156,10 @@ var usePrivate_m4_m1;
     var f3 = private_m4.foo();
 })(usePrivate_m4_m1 = exports.usePrivate_m4_m1 || (exports.usePrivate_m4_m1 = {}));
 // Do not emit unused import
-var m5 = require("importDecl_require4");
+var m5 = require("./importDecl_require4");
 exports.d = m5.foo2();
 // Do not emit multiple used import statements
-var multiImport_m4 = require("importDecl_require"); // Emit used
+var multiImport_m4 = require("./importDecl_require"); // Emit used
 exports.useMultiImport_m4_x4 = multiImport_m4.x;
 exports.useMultiImport_m4_d4 = multiImport_m4.d;
 exports.useMultiImport_m4_f4 = multiImport_m4.foo();
@@ -189,7 +189,7 @@ export declare class d {
 export declare var x: d;
 export declare function foo(): d;
 //// [importDecl_require4.d.ts]
-import m4 = require("importDecl_require");
+import m4 = require("./importDecl_require");
 export declare function foo2(): m4.d;
 //// [importDecl_1.d.ts]
 /// <reference path="importDecl_require.d.ts" />
@@ -197,7 +197,7 @@ export declare function foo2(): m4.d;
 /// <reference path="importDecl_require2.d.ts" />
 /// <reference path="importDecl_require3.d.ts" />
 /// <reference path="importDecl_require4.d.ts" />
-import m4 = require("importDecl_require");
+import m4 = require("./importDecl_require");
 export declare var x4: m4.d;
 export declare var d4: typeof m4.d;
 export declare var f4: m4.d;
@@ -206,10 +206,10 @@ export declare module m1 {
     var d2: typeof m4.d;
     var f2: m4.d;
 }
-import glo_m4 = require("importDecl_require1");
+import glo_m4 = require("./importDecl_require1");
 export declare var useGlo_m4_d4: typeof glo_m4.d;
 export declare var useGlo_m4_f4: glo_m4.d;
-import fncOnly_m4 = require("importDecl_require2");
+import fncOnly_m4 = require("./importDecl_require2");
 export declare var useFncOnly_m4_f4: fncOnly_m4.d;
 export declare module usePrivate_m4_m1 {
 }
