@@ -7,7 +7,7 @@ export class B {
 
 //// [importDeclarationUsedAsTypeQuery_1.ts]
 ///<reference path='importDeclarationUsedAsTypeQuery_require.ts'/>
-import a = require('importDeclarationUsedAsTypeQuery_require');
+import a = require('./importDeclarationUsedAsTypeQuery_require');
 export var x: typeof a;
 
 
@@ -27,5 +27,5 @@ export declare class B {
 }
 //// [importDeclarationUsedAsTypeQuery_1.d.ts]
 /// <reference path="importDeclarationUsedAsTypeQuery_require.d.ts" />
-import a = require('importDeclarationUsedAsTypeQuery_require');
+import a = require('./importDeclarationUsedAsTypeQuery_require');
 export declare var x: typeof a;
