@@ -5,7 +5,7 @@ export class Super { foo: string; }
 
 //// [importUsedInExtendsList1_1.ts]
 ///<reference path='importUsedInExtendsList1_require.ts'/>
-import foo = require('importUsedInExtendsList1_require');
+import foo = require('./importUsedInExtendsList1_require');
 class Sub extends foo.Super { }
 var s: Sub;
 var r: string = s.foo;
@@ -25,7 +25,7 @@ var __extends = (this && this.__extends) || function (d, b) {
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 ///<reference path='importUsedInExtendsList1_require.ts'/>
-var foo = require('importUsedInExtendsList1_require');
+var foo = require('./importUsedInExtendsList1_require');
 var Sub = (function (_super) {
     __extends(Sub, _super);
     function Sub() {
