@@ -9,12 +9,8 @@ var x4 = bar({ zero: 0, one: 1 });  // type should be number
 
 
 //// [indexSignaturesInferentialTyping.js]
-function foo(items) {
-    return undefined;
-}
-function bar(items) {
-    return undefined;
-}
+function foo(items) { return undefined; }
+function bar(items) { return undefined; }
 var x1 = foo({ 0: 0, 1: 1 }); // type should be number
 var x2 = foo({ zero: 0, one: 1 });
 var x3 = bar({ 0: 0, 1: 1 });
