@@ -11,17 +11,15 @@ class C extends B {
 
 
 //// [inheritanceGrandParentPrivateMemberCollisionWithPublicMember.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function () {
     function A() {
     }
-    A.prototype.myMethod = function () {
-    };
+    A.prototype.myMethod = function () { };
     return A;
 })();
 var B = (function (_super) {
@@ -36,7 +34,6 @@ var C = (function (_super) {
     function C() {
         _super.apply(this, arguments);
     }
-    C.prototype.myMethod = function () {
-    };
+    C.prototype.myMethod = function () { };
     return C;
 })(B);
