@@ -18,6 +18,5 @@ var M;
         return Foo;
     })();
     M.Foo = Foo;
-    var bar = function () {
-    };
+    var bar = function () { };
 })(M || (M = {}));
