@@ -14,9 +14,7 @@ var x = outer(); // should work
 
 //// [innerOverloads.js]
 function outer() {
-    function inner(a) {
-        return a;
-    }
+    function inner(a) { return a; }
     return inner(0);
 }
 var x = outer(); // should work
