@@ -24,9 +24,7 @@ var Point = (function () {
         var dy = this.y - p.y;
         return Math.sqrt(dx * dx + dy * dy);
     };
-    Point.distance = function (p1, p2) {
-        return p1.distance(p2);
-    };
+    Point.distance = function (p1, p2) { return p1.distance(p2); };
     Point.origin = new Point(0, 0);
     return Point;
 })();
