@@ -7,10 +7,13 @@ var x2: Function;
 var a: {};
 var b: Object;
 var c: C;
+var d: string | C;
 
 var r1 = a instanceof x1;
 var r2 = b instanceof x2;
 var r3 = c instanceof x1;
+var r4 = d instanceof x1;
+
 
 //// [instanceofOperatorWithLHSIsObject.js]
 var C = (function () {
@@ -23,6 +26,8 @@ var x2;
 var a;
 var b;
 var c;
+var d;
 var r1 = a instanceof x1;
 var r2 = b instanceof x2;
 var r3 = c instanceof x1;
+var r4 = d instanceof x1;
