@@ -19,11 +19,10 @@ class Location {
 
 
 //// [interfaceExtendsClass1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Control = (function () {
     function Control() {
@@ -35,8 +34,7 @@ var Button = (function (_super) {
     function Button() {
         _super.apply(this, arguments);
     }
-    Button.prototype.select = function () {
-    };
+    Button.prototype.select = function () { };
     return Button;
 })(Control);
 var TextBox = (function (_super) {
@@ -44,8 +42,7 @@ var TextBox = (function (_super) {
     function TextBox() {
         _super.apply(this, arguments);
     }
-    TextBox.prototype.select = function () {
-    };
+    TextBox.prototype.select = function () { };
     return TextBox;
 })(Control);
 var Image = (function (_super) {
@@ -58,7 +55,6 @@ var Image = (function (_super) {
 var Location = (function () {
     function Location() {
     }
-    Location.prototype.select = function () {
-    };
+    Location.prototype.select = function () { };
     return Location;
 })();
