@@ -28,19 +28,16 @@ c = d;
 d = c; // error
 
 //// [interfaceExtendsClassWithPrivate1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C = (function () {
     function C() {
         this.x = 1;
     }
-    C.prototype.foo = function (x) {
-        return x;
-    };
+    C.prototype.foo = function (x) { return x; };
     return C;
 })();
 var D = (function (_super) {
@@ -48,14 +45,9 @@ var D = (function (_super) {
     function D() {
         _super.apply(this, arguments);
     }
-    D.prototype.foo = function (x) {
-        return x;
-    };
-    D.prototype.other = function (x) {
-        return x;
-    };
-    D.prototype.bar = function () {
-    };
+    D.prototype.foo = function (x) { return x; };
+    D.prototype.other = function (x) { return x; };
+    D.prototype.bar = function () { };
     return D;
 })(C);
 var c;
