@@ -19,7 +19,6 @@ class C4 implements I1 {
 var C4 = (function () {
     function C4() {
     }
-    C4.prototype.iFn = function () {
-    };
+    C4.prototype.iFn = function () { };
     return C4;
 })();
