@@ -17,7 +17,6 @@ class C5 implements I1 {
 var C5 = (function () {
     function C5() {
     }
-    C5.prototype.iFn = function () {
-    };
+    C5.prototype.iFn = function () { };
     return C5;
 })();
