@@ -14,8 +14,6 @@ var Camera = (function () {
     function Camera(str) {
         this.str = str;
     }
-    Camera.prototype.foo = function () {
-        return "s";
-    };
+    Camera.prototype.foo = function () { return "s"; };
     return Camera;
 })();
