@@ -27,6 +27,6 @@ var a;
 var c;
 (function (c) {
     var b = a.weekend;
-    c.bVal = 2 /* Sunday */;
+    c.bVal = b.Sunday;
 })(c = exports.c || (exports.c = {}));
 var happyFriday = c.b.Friday;
