@@ -21,28 +21,21 @@ function fn11(): D { return new C(); }
 
 
 //// [invalidReturnStatements.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 // all the following should be error
-function fn1() {
-}
-function fn2() {
-}
-function fn3() {
-}
-function fn4() {
-}
-function fn7() {
-} // should be valid: any includes void
+function fn1() { }
+function fn2() { }
+function fn3() { }
+function fn4() { }
+function fn7() { } // should be valid: any includes void
 var C = (function () {
     function C() {
     }
-    C.prototype.dispose = function () {
-    };
+    C.prototype.dispose = function () { };
     return C;
 })();
 var D = (function (_super) {
@@ -52,9 +45,5 @@ var D = (function (_super) {
     }
     return D;
 })(C);
-function fn10() {
-    return { id: 12 };
-}
-function fn11() {
-    return new C();
-}
+function fn10() { return { id: 12 }; }
+function fn11() { return new C(); }
