@@ -28,7 +28,7 @@ var E;
     E[E["A"] = 0] = "A";
 })(E || (E = {}));
 E = x;
-0 /* A */ = x;
+E.A = x;
 var C = (function () {
     function C() {
     }
@@ -44,7 +44,6 @@ var M;
     M.x = 1;
 })(M || (M = {}));
 M = x;
-function i(a) {
-}
+function i(a) { }
 // BUG 767030
 i = x;
