@@ -20,10 +20,8 @@ let l3, l4, l5, l6;
 let l7 = false;
 let l8 = 23;
 let l9 = 0, l10 = "", l11 = null;
-for (let l11 in {}) {
-}
-for (let l12 = 0; l12 < 9; l12++) {
-}
+for (let l11 in {}) { }
+for (let l12 = 0; l12 < 9; l12++) { }
 
 
 //// [letDeclarations.d.ts]
