@@ -9,7 +9,7 @@ export = server;
 
 //// [localAliasExportAssignment_1.ts]
 ///<reference path='localAliasExportAssignment_0.ts'/>
-import connect = require('localAliasExportAssignment_0');
+import connect = require('./localAliasExportAssignment_0');
 
 connect();
 
@@ -21,5 +21,5 @@ var server;
 module.exports = server;
 //// [localAliasExportAssignment_1.js]
 ///<reference path='localAliasExportAssignment_0.ts'/>
-var connect = require('localAliasExportAssignment_0');
+var connect = require('./localAliasExportAssignment_0');
 connect();
