@@ -27,10 +27,9 @@ var Keyboard;
 var App;
 (function (App) {
     var Key = Keyboard.Key;
-    function foo(key) {
-    }
+    function foo(key) { }
     App.foo = foo;
-    foo(0 /* UP */);
-    foo(1 /* DOWN */);
-    foo(2 /* LEFT */);
+    foo(Key.UP);
+    foo(Key.DOWN);
+    foo(Key.LEFT);
 })(App || (App = {}));
