@@ -22,11 +22,8 @@ c2.b();
 var CalcButton = (function () {
     function CalcButton() {
     }
-    CalcButton.prototype.a = function () {
-        this.onClick();
-    };
-    CalcButton.prototype.onClick = function () {
-    };
+    CalcButton.prototype.a = function () { this.onClick(); };
+    CalcButton.prototype.onClick = function () { };
     return CalcButton;
 })();
 var CalcButton2 = (function () {
@@ -36,8 +33,7 @@ var CalcButton2 = (function () {
         var _this = this;
         (function () { return _this.onClick(); });
     };
-    CalcButton2.prototype.onClick = function () {
-    };
+    CalcButton2.prototype.onClick = function () { };
     return CalcButton2;
 })();
 var c = new CalcButton();
