@@ -15,11 +15,10 @@ class Test1 extends C1<M2.M2C> {
 define(["require", "exports"], function (require, exports) {
 });
 //// [moduleImportedForTypeArgumentPosition_1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 define(["require", "exports"], function (require, exports) {
     var C1 = (function () {
