@@ -22,12 +22,9 @@ c.foo = C.foo;
 var C = (function () {
     function C(x) {
     }
-    C.prototype.foo = function () {
-    };
-    C.prototype.bar = function () {
-    };
-    C.boo = function () {
-    };
+    C.prototype.foo = function () { };
+    C.prototype.bar = function () { };
+    C.boo = function () { };
     return C;
 })();
 var C;
@@ -37,12 +34,9 @@ var C;
 })(C || (C = {}));
 var C;
 (function (C) {
-    function foo() {
-    }
+    function foo() { }
     C.foo = foo;
-    function baz() {
-        return '';
-    }
+    function baz() { return ''; }
 })(C || (C = {}));
 var c = new C(C.x);
 c.foo = C.foo;
