@@ -13,16 +13,14 @@ var r2 = new C(2); // using void returning function as constructor
 var r3 = C.foo();
 
 //// [multiModuleFundule1.js]
-function C(x) {
-}
+function C(x) { }
 var C;
 (function (C) {
     C.x = 1;
 })(C || (C = {}));
 var C;
 (function (C) {
-    function foo() {
-    }
+    function foo() { }
     C.foo = foo;
 })(C || (C = {}));
 var r = C(2);
