@@ -11,18 +11,15 @@ var test = new foo<string>();
 
 
 //// [mutuallyRecursiveGenericBaseTypes2.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var foo = (function () {
     function foo() {
     }
-    foo.prototype.bar = function () {
-        return null;
-    };
+    foo.prototype.bar = function () { return null; };
     return foo;
 })();
 var foo2 = (function (_super) {
