@@ -41,10 +41,10 @@ module T {
     interface fi { } // ok
 
     class cli { }
-    interface cli { } // error
+    interface cli { }
 
     interface cli2 { }
-    class cli2 { } // error
+    class cli2 { }
 }
 
 //// [nameCollisions.js]
@@ -102,5 +102,5 @@ var T;
         function cli2() {
         }
         return cli2;
-    })(); // error
+    })();
 })(T || (T = {}));
