@@ -17,9 +17,7 @@ var M;
         }
         C.prototype.foo = function () {
             var _this = this;
-            [1, 2, 3].map(function (x) {
-                return _this.n * x;
-            });
+            [1, 2, 3].map(function (x) { return _this.n * x; });
         };
         return C;
     })();
