@@ -12,7 +12,5 @@ var console;
 var _this = 5;
 function x() {
     var _this = this;
-    (function (x) {
-        console.log(_this);
-    });
+    (function (x) { console.log(_this); });
 }
