@@ -8,9 +8,7 @@ class List<T extends {}> {
 var List = (function () {
     function List() {
     }
-    List.empty = function () {
-        return null;
-    };
+    List.empty = function () { return null; };
     return List;
 })();
 
