@@ -25,7 +25,6 @@ var One;
     })(A || (A = {}));
     var B;
     (function (B) {
-        B.x;
     })(B || (B = {}));
 })(One || (One = {}));
 var One;
@@ -36,7 +35,6 @@ var One;
     })(A || (A = {}));
     var B;
     (function (B) {
-        B.y;
     })(B || (B = {}));
     B.x;
     B.y;
