@@ -8,8 +8,7 @@ var result: Foo = x["one"]; // error
 var Foo = (function () {
     function Foo() {
     }
-    Foo.prototype.foo = function () {
-    };
+    Foo.prototype.foo = function () { };
     return Foo;
 })();
 var x;
