@@ -8,8 +8,7 @@ x = a;
 var Foo = (function () {
     function Foo() {
     }
-    Foo.prototype.foo = function () {
-    };
+    Foo.prototype.foo = function () { };
     return Foo;
 })();
 var x;
