@@ -14,8 +14,7 @@ f2({ toString: (s: string) => s }) // error, missing property value from ArgsStr
 f2({ value: '', toString: (s) => s.uhhh }) // error
 
 //// [objectLiteralFunctionArgContextualTyping.js]
-function f2(args) {
-}
+function f2(args) { }
 f2({ hello: 1 }); // error 
 f2({ value: '' }); // missing toString satisfied by Object's member
 f2({ value: '', what: 1 }); // missing toString satisfied by Object's member
