@@ -32,8 +32,7 @@ var x3 = {
     a: 0,
     b: b,
     c: c,
-    d: function () {
-    },
+    d: function () { },
     x3: x3,
     parent: x3
 };
