@@ -32,8 +32,7 @@ var r4: void = b.valueOf();
 var C = (function () {
     function C() {
     }
-    C.prototype.valueOf = function () {
-    };
+    C.prototype.valueOf = function () { };
     return C;
 })();
 var c;
@@ -41,8 +40,7 @@ var r1 = c.valueOf();
 var i;
 var r2 = i.valueOf();
 var a = {
-    valueOf: function () {
-    }
+    valueOf: function () { }
 };
 var r3 = a.valueOf();
 var b;
