@@ -29,16 +29,14 @@ i = o; // ok
 var C = (function () {
     function C() {
     }
-    C.prototype.toString = function () {
-    };
+    C.prototype.toString = function () { };
     return C;
 })();
 var c;
 o = c; // error
 c = o; // ok
 var a = {
-    toString: function () {
-    }
+    toString: function () { }
 };
 o = a; // error
 a = o; // ok
