@@ -15,5 +15,4 @@ function foo(x: B); // error after constraints above made illegal
 function foo(x: any) { }
 
 //// [objectTypesIdentityWithComplexConstraints.js]
-function foo(x) {
-}
+function foo(x) { }
