@@ -26,11 +26,10 @@ var c3: C3<T2>;
 <C4>c3; // Should fail (private x originates in the same declaration, but different types)
 
 //// [objectTypesIdentityWithPrivates3.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C1 = (function () {
     function C1() {
