@@ -11,17 +11,15 @@ d2.foo();
 
 
 //// [optionalConstructorArgInSuper.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Base = (function () {
     function Base(opt) {
     }
-    Base.prototype.foo = function (other) {
-    };
+    Base.prototype.foo = function (other) { };
     return Base;
 })();
 var Derived = (function (_super) {
