@@ -8,17 +8,15 @@ class Y extends Z {
 
 
 //// [optionalParamInOverride.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Z = (function () {
     function Z() {
     }
-    Z.prototype.func = function () {
-    };
+    Z.prototype.func = function () { };
     return Z;
 })();
 var Y = (function (_super) {
@@ -26,7 +24,6 @@ var Y = (function (_super) {
     function Y() {
         _super.apply(this, arguments);
     }
-    Y.prototype.func = function (value) {
-    };
+    Y.prototype.func = function (value) { };
     return Y;
 })(Z);
