@@ -18,9 +18,7 @@ class foo {
 //// [overloadCallTest.js]
 var foo = (function () {
     function foo() {
-        function bar(foo) {
-            return "foo";
-        }
+        function bar(foo) { return "foo"; }
         ;
         var test = bar("test");
         var goo = bar();
