@@ -6,5 +6,4 @@ interface I {
 var i2: I = { x1: (a: number, cb: (x: 'hi') => number) => { } }; // error
 
 //// [overloadOnConstInObjectLiteralImplementingAnInterface.js]
-var i2 = { x1: function (a, cb) {
-} }; // error
+var i2 = { x1: function (a, cb) { } }; // error
