@@ -35,15 +35,7 @@ var C = (function () {
     return C;
 })();
 var c;
-c.x1(1, function (x) {
-    return 1;
-});
-c.x1(1, function (x) {
-    return 1;
-});
-c.x1(1, function (x) {
-    return 1;
-});
-c.x1(1, function (x) {
-    return 1;
-});
+c.x1(1, function (x) { return 1; });
+c.x1(1, function (x) { return 1; });
+c.x1(1, function (x) { return 1; });
+c.x1(1, function (x) { return 1; });
