@@ -9,7 +9,6 @@ class C {
 var C = (function () {
     function C() {
     }
-    C.prototype.x1 = function (a) {
-    };
+    C.prototype.x1 = function (a) { };
     return C;
 })();
