@@ -12,17 +12,15 @@ function foo(name: "DIV"): Derived2 {
 foo("HI");
 
 //// [overloadOnConstantsInvalidOverload1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Base = (function () {
     function Base() {
     }
-    Base.prototype.foo = function () {
-    };
+    Base.prototype.foo = function () { };
     return Base;
 })();
 var Derived1 = (function (_super) {
@@ -30,8 +28,7 @@ var Derived1 = (function (_super) {
     function Derived1() {
         _super.apply(this, arguments);
     }
-    Derived1.prototype.bar = function () {
-    };
+    Derived1.prototype.bar = function () { };
     return Derived1;
 })(Base);
 var Derived2 = (function (_super) {
@@ -39,8 +36,7 @@ var Derived2 = (function (_super) {
     function Derived2() {
         _super.apply(this, arguments);
     }
-    Derived2.prototype.baz = function () {
-    };
+    Derived2.prototype.baz = function () { };
     return Derived2;
 })(Base);
 var Derived3 = (function (_super) {
@@ -48,8 +44,7 @@ var Derived3 = (function (_super) {
     function Derived3() {
         _super.apply(this, arguments);
     }
-    Derived3.prototype.biz = function () {
-    };
+    Derived3.prototype.biz = function () { };
     return Derived3;
 })(Base);
 function foo(name) {
