@@ -26,23 +26,17 @@ function foo4(bar:{a:any;}):any{ return bar };
 var x = foo4({a:true}); // error
 
 //// [overloadResolutionTest1.js]
-function foo(bar) {
-    return bar;
-}
+function foo(bar) { return bar; }
 ;
 var x1 = foo([{ a: true }]); // works
 var x11 = foo([{ a: 0 }]); // works
 var x111 = foo([{ a: "s" }]); // error - does not match any signature
 var x1111 = foo([{ a: null }]); // works - ambiguous call is resolved to be the first in the overload set so this returns a string
-function foo2(bar) {
-    return bar;
-}
+function foo2(bar) { return bar; }
 ;
 var x2 = foo2({ a: 0 }); // works
 var x3 = foo2({ a: true }); // works
 var x4 = foo2({ a: "s" }); // error
-function foo4(bar) {
-    return bar;
-}
+function foo4(bar) { return bar; }
 ;
 var x = foo4({ a: true }); // error
