@@ -11,7 +11,6 @@ module M {
 //// [overloadsInDifferentContainersDisagreeOnAmbient.js]
 var M;
 (function (M) {
-    function f() {
-    }
+    function f() { }
     M.f = f;
 })(M || (M = {}));
