@@ -30,12 +30,8 @@ var b = {
 }
 
 //// [parametersWithNoAnnotationAreAny.js]
-function foo(x) {
-    return x;
-}
-var f = function foo(x) {
-    return x;
-};
+function foo(x) { return x; }
+var f = function foo(x) { return x; };
 var f2 = function (x) { return x; };
 var f3 = function (x) { return x; };
 var C = (function () {
