@@ -10,5 +10,5 @@ var regex5 = /**// asdf/**/ /;
 var regex1 = / asdf /;
 var regex2 = / asdf /;
 var regex3 = 1;
-var regex4 = / / *  * /asdf /;
-var regex5 = / asdf/ *  * / /;
+var regex4 = Math.pow(/ /, /asdf /);
+var regex5 = Math.pow(/ asdf/, / /);
