@@ -18,13 +18,9 @@ var x = null;
 var y = null;
 var z = null;
 var w = null;
-function f() {
-    return 3;
-}
+function f() { return 3; }
 ;
-function g(s) {
-    true;
-}
+function g(s) { true; }
 ;
 y = f;
 y = g;
