@@ -12,8 +12,7 @@ class Bar {
 var Foo = (function () {
     function Foo() {
     }
-    Foo.prototype.banana = function (x) {
-    };
+    Foo.prototype.banana = function (x) { };
     return Foo;
 })();
 var Bar = (function () {
