@@ -9,7 +9,6 @@ static public() {}
 var Outer = (function () {
     function Outer() {
     }
-    Outer.public = function () {
-    };
+    Outer.public = function () { };
     return Outer;
 })();
