@@ -2,5 +2,4 @@
 var v = { 0<T>() { } };
 
 //// [parserFunctionPropertyAssignment4.js]
-var v = { 0: function () {
-} };
+var v = { 0: function () { } };
