@@ -5,4 +5,6 @@
 2;
 
 //// [parserGreaterThanTokenAmbiguity10.js]
-1 >>> 2;
+1
+    >>>
+        2;
