@@ -9,10 +9,8 @@ var C = (function () {
     function C() {
     }
     Object.defineProperty(C.prototype, "foo", {
-        get: function () {
-        },
-        set: function (a) {
-        },
+        get: function () { },
+        set: function (a) { },
         enumerable: true,
         configurable: true
     });
