@@ -8,7 +8,6 @@ class C {
 var C = (function () {
     function C() {
     }
-    C.prototype.foo = function (a, b) {
-    };
+    C.prototype.foo = function (a, b) { };
     return C;
 })();
