@@ -38,20 +38,15 @@ var ResultIsNumber7 = +A.foo();
 //// [plusOperatorWithBooleanType.js]
 // + operator on boolean type
 var BOOLEAN;
-function foo() {
-    return true;
-}
+function foo() { return true; }
 var A = (function () {
     function A() {
     }
-    A.foo = function () {
-        return false;
-    };
+    A.foo = function () { return false; };
     return A;
 })();
 var M;
 (function (M) {
-    M.n;
 })(M || (M = {}));
 var objA = new A();
 // boolean type var
