@@ -372,7 +372,6 @@ var m1;
         }
         m1_M1_public.f1 = f1;
         m1_M1_public.v1 = c1;
-        m1_M1_public.v2;
     })(m1_M1_public = m1.m1_M1_public || (m1.m1_M1_public = {}));
     var m1_M2_private;
     (function (m1_M2_private) {
@@ -387,7 +386,6 @@ var m1;
         }
         m1_M2_private.f1 = f1;
         m1_M2_private.v1 = c1;
-        m1_M2_private.v2;
     })(m1_M2_private || (m1_M2_private = {}));
     //export declare module "m1_M3_public" {
     //    export function f1();
@@ -457,7 +455,6 @@ var m2;
         }
         m2_M1_public.f1 = f1;
         m2_M1_public.v1 = c1;
-        m2_M1_public.v2;
     })(m2_M1_public = m2.m2_M1_public || (m2.m2_M1_public = {}));
     var m2_M2_private;
     (function (m2_M2_private) {
@@ -472,7 +469,6 @@ var m2;
         }
         m2_M2_private.f1 = f1;
         m2_M2_private.v1 = c1;
-        m2_M2_private.v2;
     })(m2_M2_private || (m2_M2_private = {}));
     //export declare module "m2_M3_public" {
     //    export function f1();
@@ -541,7 +537,6 @@ var glo_M1_public;
     }
     glo_M1_public.f1 = f1;
     glo_M1_public.v1 = c1;
-    glo_M1_public.v2;
 })(glo_M1_public = exports.glo_M1_public || (exports.glo_M1_public = {}));
 //export declare module "glo_M2_public" {
 //    export function f1();
@@ -563,7 +558,6 @@ var glo_M3_private;
     }
     glo_M3_private.f1 = f1;
     glo_M3_private.v1 = c1;
-    glo_M3_private.v2;
 })(glo_M3_private = exports.glo_M3_private || (exports.glo_M3_private = {}));
 //export declare module "glo_M4_private" {
 //    export function f1();
