@@ -16,11 +16,10 @@ module D {
 
 //// [privateStaticNotAccessibleInClodule2.js]
 // Any attempt to access a private property member outside the class body that contains its declaration results in a compile-time error.
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C = (function () {
     function C() {
