@@ -3,8 +3,7 @@ var test;
     var ClassA = (function () {
         function ClassA() {
         }
-        ClassA.prototype.method = function () {
-        };
+        ClassA.prototype.method = function () { };
         return ClassA;
     })();
     test.ClassA = ClassA;
