@@ -19,7 +19,7 @@ var Chain = (function () {
     Chain.prototype.then = function (cb) {
         var result = cb(this.value);
         // should get a fresh type parameter which each then call
-        var z = this.then(function (x) { return result; }).then(function (x) { return "abc"; }).then(function (x) { return x.length; }) /*number*/; // No error
+        var z = this.then(function (x) { return result; }) /*S*/.then(function (x) { return "abc"; }) /*string*/.then(function (x) { return x.length; }); // No error
         return new Chain(result);
     };
     return Chain;
