@@ -19,7 +19,7 @@ var Chain2 = (function () {
     Chain2.prototype.then = function (cb) {
         var result = cb(this.value);
         // should get a fresh type parameter which each then call
-        var z = this.then(function (x) { return result; }).then(function (x) { return "abc"; }).then(function (x) { return x.length; }) /*number*/; // Should error on "abc" because it is not a Function
+        var z = this.then(function (x) { return result; }) /*S*/.then(function (x) { return "abc"; }) /*Function*/.then(function (x) { return x.length; }); // Should error on "abc" because it is not a Function
         return new Chain2(result);
     };
     return Chain2;
