@@ -31,9 +31,7 @@ var Foo = (function () {
     Foo.prototype.foo = function () {
         return this._store.length; // shouldn't be an error
     };
-    Foo.prototype.bar = function () {
-        return this.store;
-    }; // should be an error
+    Foo.prototype.bar = function () { return this.store; }; // should be an error
     return Foo;
 })();
 var Bar = (function () {
