@@ -13,11 +13,8 @@ A.a();
 //// [qualifiedModuleLocals.js]
 var A;
 (function (A) {
-    function b() {
-    }
-    function a() {
-        A.b();
-    }
+    function b() { }
+    function a() { A.b(); }
     A.a = a; // A.b should be an unresolved symbol error
 })(A || (A = {}));
 A.a();
