@@ -7,7 +7,6 @@ class Test1 {
 var Test1 = (function () {
     function Test1() {
     }
-    Test1.prototype["prop1"] = function () {
-    };
+    Test1.prototype["prop1"] = function () { };
     return Test1;
 })();
