@@ -3,11 +3,10 @@ class M<T> extends M<string> { }
 (new M).blah;
 
 //// [recursiveBaseCheck4.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var M = (function (_super) {
     __extends(M, _super);
