@@ -13,8 +13,6 @@ var C = (function () {
     function C() {
         this.x = 1;
     }
-    C.prototype.foo = function (x) {
-        return x;
-    };
+    C.prototype.foo = function (x) { return x; };
     return C;
 })();
