@@ -12,9 +12,7 @@ var A = (function () {
     function A() {
     }
     Object.defineProperty(A.prototype, "testProp", {
-        get: function () {
-            return this.testProp;
-        },
+        get: function () { return this.testProp; },
         enumerable: true,
         configurable: true
     });
@@ -24,9 +22,7 @@ var B = (function () {
     function B() {
     }
     Object.defineProperty(B.prototype, "testProp", {
-        set: function (value) {
-            this.testProp = value;
-        },
+        set: function (value) { this.testProp = value; },
         enumerable: true,
         configurable: true
     });
