@@ -20,9 +20,7 @@ function R1() {
     R1();
     return;
 }
-function R2() {
-    R2();
-}
+function R2() { R2(); }
 function R3(n) {
     if (n == 0) {
     }
