@@ -3,7 +3,7 @@
 //// [requireOfAnEmptyFile1_a.ts]
 //requireOfAnEmptyFile1
 
-import fs = require('requireOfAnEmptyFile1_b');
+import fs = require('./requireOfAnEmptyFile1_b');
 
 //// [requireOfAnEmptyFile1_b.ts]
 
