@@ -6,7 +6,6 @@ module X {
 //// [separate1-2.js]
 var X;
 (function (X) {
-    function f() {
-    }
+    function f() { }
     X.f = f;
 })(X || (X = {}));
