@@ -4,17 +4,15 @@ class derived extends base { private n() {} }
 
 
 //// [shadowPrivateMembers.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var base = (function () {
     function base() {
     }
-    base.prototype.n = function () {
-    };
+    base.prototype.n = function () { };
     return base;
 })();
 var derived = (function (_super) {
@@ -22,7 +20,6 @@ var derived = (function (_super) {
     function derived() {
         _super.apply(this, arguments);
     }
-    derived.prototype.n = function () {
-    };
+    derived.prototype.n = function () { };
     return derived;
 })(base);
