@@ -13,17 +13,15 @@ function g(tagName: any): Base {
 }
 
 //// [specializedOverloadWithRestParameters.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Base = (function () {
     function Base() {
     }
-    Base.prototype.foo = function () {
-    };
+    Base.prototype.foo = function () { };
     return Base;
 })();
 var Derived1 = (function (_super) {
@@ -31,8 +29,7 @@ var Derived1 = (function (_super) {
     function Derived1() {
         _super.apply(this, arguments);
     }
-    Derived1.prototype.bar = function () {
-    };
+    Derived1.prototype.bar = function () { };
     return Derived1;
 })(Base);
 function f(tagName) {
