@@ -8,9 +8,7 @@ class T {
 var T = (function () {
     function T() {
     }
-    T.x = function () {
-    };
-    T.prototype.y = function () {
-    };
+    T.x = function () { };
+    T.prototype.y = function () { };
     return T;
 })();
