@@ -14,18 +14,15 @@ var d = Derived.create();
 d.foo();  
 
 //// [staticFactory1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var Base = (function () {
     function Base() {
     }
-    Base.prototype.foo = function () {
-        return 1;
-    };
+    Base.prototype.foo = function () { return 1; };
     Base.create = function () {
         return new this();
     };
@@ -36,9 +33,7 @@ var Derived = (function (_super) {
     function Derived() {
         _super.apply(this, arguments);
     }
-    Derived.prototype.foo = function () {
-        return 2;
-    };
+    Derived.prototype.foo = function () { return 2; };
     return Derived;
 })(Base);
 var d = Derived.create();
