@@ -9,7 +9,7 @@ export class Promise {
 
 //// [staticInstanceResolution3_1.ts]
 ///<reference path='staticInstanceResolution3_0.ts'/>
-import WinJS = require('staticInstanceResolution3_0');
+import WinJS = require('./staticInstanceResolution3_0');
 WinJS.Promise.timeout(10);
 
 //// [staticInstanceResolution3_0.js]
@@ -24,5 +24,5 @@ var Promise = (function () {
 exports.Promise = Promise;
 //// [staticInstanceResolution3_1.js]
 ///<reference path='staticInstanceResolution3_0.ts'/>
-var WinJS = require('staticInstanceResolution3_0');
+var WinJS = require('./staticInstanceResolution3_0');
 WinJS.Promise.timeout(10);
