@@ -9,8 +9,7 @@ A.foo();
 var A = (function () {
     function A() {
     }
-    A.prototype.foo = function () {
-    };
+    A.prototype.foo = function () { };
     return A;
 })();
 A.foo();
