@@ -24,9 +24,7 @@ Sammy.bar();
 var Sammy = (function () {
     function Sammy() {
     }
-    Sammy.prototype.foo = function () {
-        return "hi";
-    };
+    Sammy.prototype.foo = function () { return "hi"; };
     Sammy.bar = function () {
         return -1;
     };
