@@ -7,8 +7,6 @@ class C<T> {
 var C = (function () {
     function C() {
     }
-    C.s = function (p) {
-        return p;
-    };
+    C.s = function (p) { return p; };
     return C;
 })();
