@@ -13,7 +13,6 @@ var List = (function () {
     List.prototype.Blah = function () {
         this.Foo();
     };
-    List.Foo = function () {
-    };
+    List.Foo = function () { };
     return List;
 })();
