@@ -11,8 +11,7 @@ class C2 {
 var C = (function () {
     function C() {
     }
-    C.prototype = function () {
-    };
+    C.prototype = function () { };
     return C;
 })();
 var C2 = (function () {
