@@ -41,18 +41,15 @@ var b: { [x: string]: A } = {
 
 //// [stringIndexerConstrainsPropertyDeclarations2.js]
 // String indexer providing a constraint of a user defined type
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function () {
     function A() {
     }
-    A.prototype.foo = function () {
-        return '';
-    };
+    A.prototype.foo = function () { return ''; };
     return A;
 })();
 var B = (function (_super) {
@@ -60,9 +57,7 @@ var B = (function (_super) {
     function B() {
         _super.apply(this, arguments);
     }
-    B.prototype.bar = function () {
-        return '';
-    };
+    B.prototype.bar = function () { return ''; };
     return B;
 })(A);
 var Foo = (function () {
