@@ -13,7 +13,9 @@ class T6 extends T5<number>{
 
     constructor() {
 
-        super("hi"); // Should error, base constructor has type T for first arg, which is fixed as number in the extends clause
+        // Should error; base constructor has type T for first arg,
+        // which is instantiated with 'number' in the extends clause
+        super("hi");
 
         var x: number = this.foo;
 
@@ -24,11 +26,10 @@ class T6 extends T5<number>{
 
 
 //// [superCallArgsMustMatch.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var T5 = (function () {
     function T5(bar) {
@@ -39,7 +40,9 @@ var T5 = (function () {
 var T6 = (function (_super) {
     __extends(T6, _super);
     function T6() {
-        _super.call(this, "hi"); // Should error, base constructor has type T for first arg, which is fixed as number in the extends clause
+        // Should error; base constructor has type T for first arg,
+        // which is instantiated with 'number' in the extends clause
+        _super.call(this, "hi");
         var x = this.foo;
     }
     return T6;
