@@ -21,19 +21,16 @@ class Derived extends Base {
 }
 
 //// [superCallsInConstructor.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C = (function () {
     function C() {
     }
-    C.prototype.foo = function () {
-    };
-    C.prototype.bar = function () {
-    };
+    C.prototype.foo = function () { };
+    C.prototype.bar = function () { };
     return C;
 })();
 var Base = (function () {
@@ -49,8 +46,7 @@ var Derived = (function (_super) {
             _super.call(this);
             bar();
         }
-        try {
-        }
+        try { }
         catch (e) {
             _super.call(this);
         }
