@@ -14,17 +14,15 @@ class B extends A {
 
 
 //// [superInCatchBlock1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var A = (function () {
     function A() {
     }
-    A.prototype.m = function () {
-    };
+    A.prototype.m = function () { };
     return A;
 })();
 var B = (function (_super) {
