@@ -25,12 +25,13 @@ var Foo = (function () {
     return Foo;
 })();
 switch (0) {
-    case Foo: break;
-    case "sss": break;
-    case 123: break;
-    case true: break;
+    case Foo: break; // Error
+    case "sss": break; // Error
+    case 123: break; // No Error
+    case true: break; // Error
 }
 var s = 0;
+// No error for all
 switch (s) {
     case Foo: break;
     case "sss": break;
