@@ -23,11 +23,7 @@ var z = foo `${1}${2}${3}`;  // any (with error)
 
 
 //// [taggedTemplateStringsWithOverloadResolution1_ES6.js]
-function foo() {
-    var stuff = [];
-    for (var _i = 0; _i < arguments.length; _i++) {
-        stuff[_i - 0] = arguments[_i];
-    }
+function foo(...stuff) {
     return undefined;
 }
 var a = foo([]); // number
