@@ -2,4 +2,4 @@
 var x = `abc${ x => x }def`;
 
 //// [templateStringWithEmbeddedArrowFunctionES6.js]
-var x = `abc${function (x) { return x; }}def`;
+var x = `abc${x => x}def`;
