@@ -2,6 +2,4 @@
 var x = `abc${ function y() { return y; } }def`;
 
 //// [templateStringWithEmbeddedFunctionExpressionES6.js]
-var x = `abc${function y() {
-    return y;
-}}def`;
+var x = `abc${function y() { return y; }}def`;
