@@ -11,11 +11,8 @@ f({}, 10, 10);
 f `abcdef${ 1234 }${ 5678 }ghijkl`;
 
 //// [templateStringsArrayTypeRedefinedInES6Mode.js]
-var TemplateStringsArray = (function () {
-    function TemplateStringsArray() {
-    }
-    return TemplateStringsArray;
-})();
+class TemplateStringsArray {
+}
 function f(x, y, z) {
 }
 f({}, 10, 10);
