@@ -40,8 +40,6 @@ var messenger = {
     message: "Hello World",
     start: function () {
         var _this = this;
-        return setTimeout(function () {
-            var x = _this.message;
-        }, 3000);
+        return setTimeout(function () { var x = _this.message; }, 3000);
     }
 };
