@@ -10,9 +10,7 @@ var C = (function () {
     }
     C.prototype.foo = function () {
         var _this = this;
-        [1, 2, 3].map(function (x) {
-            return _this;
-        });
+        [1, 2, 3].map(function (x) { return _this; });
     };
     return C;
 })();
