@@ -30,8 +30,7 @@ var Foo = (function () {
     };
     return Foo;
 })();
-function myFn(a) {
-}
+function myFn(a) { }
 var myCls = (function () {
     function myCls() {
         var _this = this;
