@@ -12,11 +12,9 @@ interface I<T> {}
 var i: I<number,number>;
 
 //// [tooManyTypeParameters1.js]
-function f() {
-}
+function f() { }
 f();
-var x = function () {
-};
+var x = function () { };
 x();
 var C = (function () {
     function C() {
