@@ -8,8 +8,6 @@ void log(foo).toString();
 //// [topLevelExports.js]
 define(["require", "exports"], function (require, exports) {
     exports.foo = 3;
-    function log(n) {
-        return n;
-    }
+    function log(n) { return n; }
     void log(exports.foo).toString();
 });
