@@ -5,6 +5,5 @@ foo(()=>this.window);
 
 //// [topLevelLambda2.js]
 var _this = this;
-function foo(x) {
-}
+function foo(x) { }
 foo(function () { return _this.window; });
