@@ -19,9 +19,13 @@ namespace M {
 	//  and M.React.__spread
 	var foo;
 	var spread1 = <div x='' {...foo} y='' />;
+
+	// Quotes
+	var x = <div>This "quote" thing</div>;
 }
 
 
+
 //// [file.js]
 //// [react-consumer.js]
 var M;
@@ -33,4 +37,6 @@ var M;
     //  and M.React.__spread
     var foo;
     var spread1 = M.React.createElement("div", M.React.__spread({x: ''}, foo, {y: ''}));
+    // Quotes
+    var x = M.React.createElement("div", null, "This \"quote\" thing");
 })(M || (M = {}));
