@@ -16,9 +16,7 @@ interface Goo {
 
 
 //// [typeArgumentInferenceOrdering.js]
-function foo(f) {
-    return null;
-}
+function foo(f) { return null; }
 var x = foo(new C()).x; // was Error that property x does not exist on type {}
 var C = (function () {
     function C() {
