@@ -8,9 +8,7 @@ var e: Elephant;
 f(g, e); // valid because both Giraffe and Elephant satisfy the constraint. T is Animal
 
 //// [typeArgumentInferenceWithConstraintAsCommonRoot.js]
-function f(x, y) {
-    return undefined;
-}
+function f(x, y) { return undefined; }
 var g;
 var e;
 f(g, e); // valid because both Giraffe and Elephant satisfy the constraint. T is Animal
