@@ -29,15 +29,11 @@ var C2 = (function () {
     }
     return C2;
 })();
-function f() {
-}
-function f2() {
-}
+function f() { }
+function f2() { }
 var a;
-var b = function () {
-};
-var b2 = function () {
-};
+var b = function () { };
+var b2 = function () { };
 var D = (function () {
     function D() {
     }
