@@ -10,8 +10,8 @@ export = D;
 //// [typeofAmbientExternalModules_2.ts]
 ///<reference path='typeofAmbientExternalModules_0.ts'/>
 ///<reference path='typeofAmbientExternalModules_1.ts'/>
-import ext = require('typeofAmbientExternalModules_0');
-import exp = require('typeofAmbientExternalModules_1');
+import ext = require('./typeofAmbientExternalModules_0');
+import exp = require('./typeofAmbientExternalModules_1');
 
 var y1: typeof ext = ext;
 y1 = exp;
@@ -35,8 +35,8 @@ module.exports = D;
 //// [typeofAmbientExternalModules_2.js]
 ///<reference path='typeofAmbientExternalModules_0.ts'/>
 ///<reference path='typeofAmbientExternalModules_1.ts'/>
-var ext = require('typeofAmbientExternalModules_0');
-var exp = require('typeofAmbientExternalModules_1');
+var ext = require('./typeofAmbientExternalModules_0');
+var exp = require('./typeofAmbientExternalModules_1');
 var y1 = ext;
 y1 = exp;
 var y2 = exp;
