@@ -22,19 +22,16 @@ var r1: typeof D;
 var r2: typeof d;
 
 //// [typeofClass2.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var C = (function () {
     function C(x) {
     }
-    C.foo = function (x) {
-    };
-    C.bar = function (x) {
-    };
+    C.foo = function (x) { };
+    C.bar = function (x) { };
     return C;
 })();
 var D = (function (_super) {
@@ -42,10 +39,8 @@ var D = (function (_super) {
     function D() {
         _super.apply(this, arguments);
     }
-    D.baz = function (x) {
-    };
-    D.prototype.foo = function () {
-    };
+    D.baz = function (x) { };
+    D.prototype.foo = function () { };
     return D;
 })(C);
 var d;
