@@ -19,7 +19,5 @@ var C2 = (function () {
     }
     return C2;
 })();
-function f() {
-}
-function f2() {
-}
+function f() { }
+function f2() { }
