@@ -7,14 +7,14 @@ m1.f();
 
 //// [umdDependencyCommentName1.js]
 ///<amd-dependency path='bar' name='b'/>
-(function (deps, factory) {
+(function (factory) {
     if (typeof module === 'object' && typeof module.exports === 'object') {
         var v = factory(require, exports); if (v !== undefined) module.exports = v;
     }
     else if (typeof define === 'function' && define.amd) {
-        define(deps, factory);
+        define(["require", "exports", "bar", "m2"], factory);
     }
-})(["require", "exports", "bar", "m2"], function (require, exports, b) {
+})(function (require, exports, b) {
     var m1 = require("m2");
     m1.f();
 });
