@@ -17,8 +17,7 @@ function instrumentFile(covFileDir: string, covFileName: string, originalFilePat
 
 //// [undeclaredModuleError.js]
 define(["require", "exports", 'fs'], function (require, exports, fs) {
-    function readdir(path, accept, callback) {
-    }
+    function readdir(path, accept, callback) { }
     function join() {
         var paths = [];
         for (var _i = 0; _i < arguments.length; _i++) {
