@@ -20,11 +20,10 @@ var z1: string | typeof BC;
 
 
 //// [unionTypeEquivalence.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 // A | B is equivalent to A if B is a subtype of A
 var C = (function () {
@@ -37,8 +36,7 @@ var D = (function (_super) {
     function D() {
         _super.apply(this, arguments);
     }
-    D.prototype.foo = function () {
-    };
+    D.prototype.foo = function () { };
     return D;
 })(C);
 var x;
