@@ -33,16 +33,14 @@ class C5 {
 }
 
 //// [unknownSymbols1.js]
-var __extends = this.__extends || function (d, b) {
+var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
-    __.prototype = b.prototype;
-    d.prototype = new __();
+    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 var x = asdf;
 var y;
-function foo(x, y) {
-}
+function foo(x, y) { }
 function foo2() {
     return asdf;
 }
