@@ -3,8 +3,8 @@
 //// [visibilityOfCrossModuleTypeUsage_commands.ts]
 //visibilityOfCrossModuleTypeUsage
 
-import fs = require('visibilityOfCrossModuleTypeUsage_fs');
-import server = require('visibilityOfCrossModuleTypeUsage_server');
+import fs = require('./visibilityOfCrossModuleTypeUsage_fs');
+import server = require('./visibilityOfCrossModuleTypeUsage_server');
 
 export interface IConfiguration {
     workspace: server.IWorkspace;
@@ -20,7 +20,7 @@ export interface IWorkspace {
 }
 
 //// [visibilityOfCrossModuleTypeUsage_fs.ts]
-import commands = require('visibilityOfCrossModuleTypeUsage_commands');
+import commands = require('./visibilityOfCrossModuleTypeUsage_commands');
 function run(configuration: commands.IConfiguration) {
     var absoluteWorkspacePath = configuration.workspace.toAbsolutePath(configuration.server);
 }
