@@ -25,13 +25,11 @@ var arr: string[] = [3, null]; // not assignable because null is not widened. BC
 var obj: { [x: string]: string; } = { x: 3, y: null }; // assignable because null is widened, and therefore BCT is any
 
 //// [widenedTypes.js]
-null instanceof (function () {
-});
+null instanceof (function () { });
 ({}) instanceof null; // Ok because null is a subtype of function
 null in {};
 "" in null;
-for (var a in null) {
-}
+for (var a in null) { }
 var t = [3, (3, null)];
 t[3] = "";
 var x = 3;
@@ -43,3 +41,17 @@ var ob = { x: "" };
 // Highlights the difference between array literals and object literals
 var arr = [3, null]; // not assignable because null is not widened. BCT is {}
 var obj = { x: 3, y: null }; // assignable because null is widened, and therefore BCT is any
+
+
+//// [widenedTypes.d.ts]
+declare var t: number[];
+declare var x: typeof undefined;
+declare var y: any;
+declare var u: number[];
+declare var ob: {
+    x: typeof undefined;
+};
+declare var arr: string[];
+declare var obj: {
+    [x: string]: string;
+};
