@@ -1,4 +1,4 @@
-//@module: commonjs
+// @module: commonjs
 // @Filename: arrayOfExportedClass_0.ts
 class Car {
     foo: string;
@@ -8,7 +8,7 @@ export = Car;
 
 // @Filename: arrayOfExportedClass_1.ts
 ///<reference path='arrayOfExportedClass_0.ts'/>
-import Car = require('arrayOfExportedClass_0');
+import Car = require('./arrayOfExportedClass_0');
 
 class Road {
 
