@@ -6,6 +6,11 @@ declare var a;
 (<any>[1,3,]); 
 (<any>"string"); 
 (<any>23.0); 
+(<any>1); 
+(<any>1.);
+(<any>1.0);
+(<any>12e+34);
+(<any>0xff);
 (<any>/regexp/g); 
 (<any>false); 
 (<any>true); 
@@ -22,6 +27,12 @@ declare var a;
 declare var A;
 
 // should keep the parentheses in emit
+(<any>1).foo;
+(<any>1.).foo;
+(<any>1.0).foo;
+(<any>12e+34).foo;
+(<any>0xff).foo;
+(<any>(1.0)); 
 (<any>new A).foo; 
 (<any>typeof A).x; 
 (<any>-A).x; 
