@@ -15,7 +15,7 @@ while (true);
 
 var obj;
 with (obj) 
-    const c5 = 0;
+    const c5 = 0;  // No  Error will be reported here since we turn off all type checking
 
 for (var i = 0; i < 10; i++)
     const c6 = 0;
