@@ -5,5 +5,5 @@
 export var a = 10;
 
 // @filename: client.ts
-export import defaultBinding, * as nameSpaceBinding  from "server";
+export import defaultBinding, * as nameSpaceBinding  from "./server";
 export var x: number = nameSpaceBinding.a;
\ No newline at end of file
