@@ -1,4 +1,4 @@
-//@module: commonjs
+// @module: commonjs
 // @declaration: true
 // @Filename: importDeclarationUsedAsTypeQuery_require.ts
 export class B {
@@ -7,5 +7,5 @@ export class B {
 
 // @Filename: importDeclarationUsedAsTypeQuery_1.ts
 ///<reference path='importDeclarationUsedAsTypeQuery_require.ts'/>
-import a = require('importDeclarationUsedAsTypeQuery_require');
+import a = require('./importDeclarationUsedAsTypeQuery_require');
 export var x: typeof a;
