@@ -1,4 +1,4 @@
-//@module: commonjs
+// @module: commonjs
 // @Filename: typeofExternalModules_external.ts
 export class C { }
 
@@ -7,8 +7,8 @@ class D { }
 export = D;
 
 // @Filename: typeofExternalModules_core.ts
-import ext = require('typeofExternalModules_external');
-import exp = require('typeofExternalModules_exportAssign');
+import ext = require('./typeofExternalModules_external');
+import exp = require('./typeofExternalModules_exportAssign');
 
 var y1: typeof ext = ext;
 y1 = exp;
