@@ -1,7 +1,7 @@
 /// <reference path="fourslash.ts" />
 
 //// 
-//// module /*check*/Mod{
+//// namespace /*check*/Mod{
 //// }
 //// 
 //// interface MyInterface {
@@ -9,13 +9,12 @@
 //// }
 
 edit.disableFormatting();
-diagnostics.setEditValidation(IncrementalEditValidation.SyntacticOnly);
 
 goTo.marker('check');
-verify.quickInfoIs('module Mod');
+verify.quickInfoIs('namespace Mod');
 
 goTo.marker('insert');
 edit.insert("x: number;\n");
 
 goTo.marker('check');
-verify.quickInfoIs('module Mod');
+verify.quickInfoIs('namespace Mod');
