@@ -13,31 +13,31 @@
 
 
 goTo.marker('1');
-verify.quickInfoIs('(var) a1: any[]');
+verify.quickInfoIs('var a1: any[]');
 
 goTo.marker('2');
-verify.quickInfoIs('(var) a2: any[]');
+verify.quickInfoIs('var a2: any[]');
 
 goTo.marker('3');
-verify.quickInfoIs('(var) a3: boolean[]');
+verify.quickInfoIs('var a3: boolean[]');
 
 goTo.marker('4');
-verify.quickInfoIs('(var) a4: boolean[]');
+verify.quickInfoIs('var a4: boolean[]');
 
 goTo.marker('5');
-verify.quickInfoIs('(var) a5: string[]');
+verify.quickInfoIs('var a5: string[]');
 
 goTo.marker('6');
-verify.quickInfoIs('(var) a6: any[]');
+verify.quickInfoIs('var a6: any[]');
 
 goTo.marker('7');
-verify.quickInfoIs('(var) a7: any[]');
+verify.quickInfoIs('var a7: any[]');
 
 goTo.marker('8');
-verify.quickInfoIs('(var) a8: boolean[]');
+verify.quickInfoIs('var a8: boolean[]');
 
 goTo.marker('9');
-verify.quickInfoIs('(var) a9: boolean[]');
+verify.quickInfoIs('var a9: boolean[]');
 
 goTo.marker('10');
-verify.quickInfoIs('(var) a10: string[]');
\ No newline at end of file
+verify.quickInfoIs('var a10: string[]');
\ No newline at end of file
