@@ -13,7 +13,7 @@ verify.not.completionListContains('foo');
 edit.backspace(1);
 
 goTo.marker('2');
-verify.quickInfoIs("(var) r: typeof m2g");
+verify.quickInfoIs("var r: typeof m2g");
 
 goTo.marker('3');
 edit.insert('(');
