@@ -20,7 +20,7 @@ goTo.marker('3');
 verify.currentSignatureHelpIs('m3f(): m3f');
 
 goTo.marker('4');
-verify.quickInfoIs('(var) r: m3f');
+verify.quickInfoIs('var r: m3f');
 
 goTo.marker('5');
 verify.completionListContains('foo');
