@@ -1,4 +1,4 @@
-﻿/// <reference path="fourslash.ts"/>
+/// <reference path="fourslash.ts"/>
 
 ////class Foo {
 ////    doStuff(): number { return 0; }
