@@ -7,10 +7,10 @@
 ////var x/*3*/3 = new SS;
 
 goTo.marker('1');
-verify.quickInfoIs('(var) x1: SS<number>');
+verify.quickInfoIs('var x1: SS<number>');
 
 goTo.marker('2');
-verify.quickInfoIs('(var) x2: SS<{}>');
+verify.quickInfoIs('var x2: SS<{}>');
 
 goTo.marker('3');
-verify.quickInfoIs('(var) x3: SS<{}>');
\ No newline at end of file
+verify.quickInfoIs('var x3: SS<{}>');
