@@ -9,4 +9,4 @@
 ////var /**/r = i[1];
 
 goTo.marker();
-verify.quickInfoIs('(var) r: string');
\ No newline at end of file
+verify.quickInfoIs('var r: string');
