@@ -4,7 +4,7 @@
 ////var y/*2*/y = true ? [1] : [];
 
 goTo.marker('1');
-verify.quickInfoIs('(var) xx: number[]');
+verify.quickInfoIs('var xx: number[]');
 
 goTo.marker('2');
-verify.quickInfoIs('(var) yy: number[]');
+verify.quickInfoIs('var yy: number[]');
