@@ -11,12 +11,12 @@ verify.numberOfErrorsInCurrentFile(1);
 // - Could not select overload for 'call' expression.
 
 goTo.marker("y");
-verify.quickInfoIs("(var) y: any");
+verify.quickInfoIs("var y: any");
 
 goTo.eof();
 edit.insert("interface Array<T> { pop(def: T): T; }");
 
 verify.not.errorExistsBetweenMarkers("1", "2");
 goTo.marker("y");
-verify.quickInfoIs("(var) y: number");
+verify.quickInfoIs("var y: number");
 verify.numberOfErrorsInCurrentFile(0);
