@@ -5,4 +5,4 @@
 
 goTo.marker();
 
-verify.quickInfoIs('(var) p: any', "");
\ No newline at end of file
+verify.quickInfoIs('var p: any', "");
