@@ -13,7 +13,7 @@
 ////var /*2*/r2 = utils.fold(c, (s, t) => t);
 
 goTo.marker('1');
-verify.quickInfoIs('(var) r: string');
+verify.quickInfoIs('var r: string');
 
 goTo.marker('2');
-verify.quickInfoIs('(var) r2: string');
\ No newline at end of file
+verify.quickInfoIs('var r2: string');
