@@ -13,11 +13,11 @@
 ////var /*4*/y2 = f2.y; 
 
 goTo.marker('1');
-verify.quickInfoIs('(var) x: Foo<string>');
+verify.quickInfoIs('var x: Foo<string>');
 goTo.marker('2');
-verify.quickInfoIs('(var) y: Foo<number>');
+verify.quickInfoIs('var y: Foo<number>');
 
 goTo.marker('3');
-verify.quickInfoIs('(var) x2: Foo<string>');
+verify.quickInfoIs('var x2: Foo<string>');
 goTo.marker('4');
-verify.quickInfoIs('(var) y2: Foo<number>');
\ No newline at end of file
+verify.quickInfoIs('var y2: Foo<number>');
