@@ -14,11 +14,11 @@
 ////var /*4*/y2 = f2.y;
 
 goTo.marker('1');
-verify.quickInfoIs('(var) xx: Foo<number, string>');
+verify.quickInfoIs('var xx: Foo<number, string>');
 goTo.marker('2');
-verify.quickInfoIs('(var) yy: Foo<string, string>');
+verify.quickInfoIs('var yy: Foo<string, string>');
 
 goTo.marker('3');
-verify.quickInfoIs('(var) x2: Foo<string, number>');
+verify.quickInfoIs('var x2: Foo<string, number>');
 goTo.marker('4');
-verify.quickInfoIs('(var) y2: Foo<number, number>');
\ No newline at end of file
+verify.quickInfoIs('var y2: Foo<number, number>');
