@@ -7,9 +7,6 @@
 ////var bbb: string;
 /////*1*/
 
-// Disable test triggered type check
-diagnostics.setEditValidation(IncrementalEditValidation.None);
-
 goTo.marker("1");
 verify.completionListContains("aaa");
 verify.completionListContains("bbb");
@@ -17,17 +14,17 @@ verify.completionListContains("ccc");
 verify.completionListContains("ddd");
 
 // Checking for completion details before edit should work
-verify.completionEntryDetailIs("aaa", "(var) aaa: number");
-verify.completionEntryDetailIs("ccc", "(var) ccc: number");
+verify.completionEntryDetailIs("aaa", "var aaa: number");
+verify.completionEntryDetailIs("ccc", "var ccc: number");
 
 // Make an edit
 edit.insert("a");
 edit.backspace();
 
 // Checking for completion details after edit should work too
-verify.completionEntryDetailIs("bbb", "(var) bbb: string");
-verify.completionEntryDetailIs("ddd", "(var) ddd: string");
+verify.completionEntryDetailIs("bbb", "var bbb: string");
+verify.completionEntryDetailIs("ddd", "var ddd: string");
 
 // Checking for completion details again before edit should work
-verify.completionEntryDetailIs("aaa", "(var) aaa: number");
-verify.completionEntryDetailIs("ccc", "(var) ccc: number");
+verify.completionEntryDetailIs("aaa", "var aaa: number");
+verify.completionEntryDetailIs("ccc", "var ccc: number");
