@@ -1,4 +1,6 @@
-﻿/// <reference path="fourslash.ts" />
+/// <reference path="fourslash.ts" />
+
+// @module: CommonJS
 
 //// interface privateInterface {}
 //// export class Bar implements /*1*/privateInterface/*2*/{ }
