@@ -12,11 +12,9 @@
 ////var b = val.p1;
 /////*1*/b;
 
-diagnostics.setEditValidation(IncrementalEditValidation.None);
-
 // Resolve without typeCheck
 goTo.marker('1');
-verify.quickInfoIs("(var) b: string");
+verify.quickInfoIs("var b: string");
 
 // TypeCheck
 verify.numberOfErrorsInCurrentFile(3);
\ No newline at end of file
