@@ -9,4 +9,4 @@
 //// }
 
 goTo.marker();
-verify.quickInfoIs("(var) x: number", "");
\ No newline at end of file
+verify.quickInfoIs("var x: number", "");
