@@ -7,4 +7,4 @@
 ////testModule./**/
 
 goTo.marker();
-verify.completionListContains('foo', '(var) testModule.foo: number');
\ No newline at end of file
+verify.completionListContains('foo', 'var testModule.foo: number');
