@@ -1,7 +1,7 @@
 /// <reference path='fourslash.ts' />
 
-//// module foo {
-////     export module bar { module baz { export class boo { } } }
+//// namespace foo {
+////     export namespace bar { namespace baz { export class boo { } } }
 //// }
 //// 
 //// import f = /*foo*/foo;
@@ -10,7 +10,7 @@
 
 // Sanity check
 goTo.marker('foo');
-verify.quickInfoIs('module foo');
+verify.quickInfoIs('namespace foo');
 
 // Delete some code
 goTo.marker('delete');
@@ -18,4 +18,4 @@ edit.deleteAtCaret('var x;'.length);
 
 // Pull on the RHS of an import
 goTo.marker('foo');
-verify.quickInfoIs('module foo');
+verify.quickInfoIs('namespace foo');
