@@ -6,4 +6,4 @@
 ////var r = M./**/;
 
 goTo.marker();
-verify.completionListContains('x', '(var) M.x: <T>(x: T) => T');
\ No newline at end of file
+verify.completionListContains('x', 'var M.x: <T>(x: T) => T');
