@@ -18,14 +18,14 @@ verify.completionListContains('C');
 edit.insert('C.x);');
 
 goTo.marker('2');
-verify.quickInfoIs('(var) r: void');
+verify.quickInfoIs('var r: void');
 
 goTo.marker('3');
 verify.completionListContains('C');
 edit.insert('C.x);');
 
 goTo.marker('4');
-verify.quickInfoIs('(var) r2: any');
+verify.quickInfoIs('var r2: any');
 
 goTo.marker('5');
 verify.completionListContains('x');
