@@ -3,4 +3,4 @@
 ////var /**/t2 = { 0: 1, 1: "" };
 
 goTo.marker();
-verify.quickInfoIs('(var) t2: {\n    0: number;\n    1: string;\n}');
\ No newline at end of file
+verify.quickInfoIs('var t2: {\n    0: number;\n    1: string;\n}');
