@@ -15,7 +15,7 @@
 //// } );
 
 goTo.marker("1");
-verify.quickInfoIs('(var) p2: IPromise<string>');
+verify.quickInfoIs('var p2: IPromise<string>');
 
 goTo.marker("2");
 verify.quickInfoIs('(parameter) xx: string');
