@@ -10,11 +10,11 @@
 goTo.marker('1');
 verify.quickInfoIs("interface M.__proto__", "");
 goTo.marker('2');
-verify.quickInfoIs("(var) __proto__: M.__proto__", "");
+verify.quickInfoIs("var __proto__: M.__proto__", "");
 goTo.marker('3');
-verify.completionListContains("__proto__", "(var) __proto__: M.__proto__", "");
+verify.completionListContains("__proto__", "var __proto__: M.__proto__", "");
 edit.insert("__proto__");
 goTo.definition();
 verify.caretAtMarker('2');
 goTo.marker('4');
-verify.quickInfoIs("(var) fun: (__proto__: any) => boolean", "");
\ No newline at end of file
+verify.quickInfoIs("var fun: (__proto__: any) => boolean", "");
