@@ -11,7 +11,7 @@
 ////var x = Alpha.[|{| "name" : "mem" |}x|]
 
 goTo.marker('import');
-verify.completionListContains('x', '(var) Alpha.x: number');
+verify.completionListContains('x', 'var Alpha.x: number');
 
 var def: FourSlashInterface.Range = test.ranges().filter(range => range.marker.data.name === "def")[0];
 var imp: FourSlashInterface.Range = test.ranges().filter(range => range.marker.data.name === "import")[0];
