@@ -13,4 +13,4 @@
 
 goTo.file("quickInfoExportAssignmentOfGenericInterface_1.ts");
 goTo.marker('1');
-verify.quickInfoIs("(var) x: a<a<string>>", undefined);
\ No newline at end of file
+verify.quickInfoIs("var x: a<a<string>>", undefined);
