@@ -3,4 +3,4 @@
 ////const /**/c = 0 ;
 
 goTo.marker();
-verify.quickInfoIs("(const) c: number");
\ No newline at end of file
+verify.quickInfoIs("const c: number");
