@@ -12,7 +12,7 @@
 ////var y = makeA(0);
 
 goTo.marker("makeA");
-verify.quickInfoIs("(function) makeA<T>(t: T): A<T>", undefined);
+verify.quickInfoIs("function makeA<T>(t: T): A<T>", undefined);
 
 goTo.marker("f");
-verify.quickInfoIs("(function) f<T>(t: T): A<T>", undefined);
\ No newline at end of file
+verify.quickInfoIs("function f<T>(t: T): A<T>", undefined);
