@@ -7,7 +7,7 @@
 ////var y = C.proto/*2*/type;
 
 goTo.marker('1');
-verify.quickInfoIs('(constructor) C<any>(): C<any>');
+verify.quickInfoIs('constructor C<any>(): C<any>');
 
 goTo.marker('2');
 verify.quickInfoIs('(property) C<T>.prototype: C<any>');
\ No newline at end of file
