@@ -26,4 +26,4 @@ verify.currentSignatureHelpIs("B(a: Foo<I>, b: number): B");
 edit.insert("10);");
 
 goTo.marker("2");
-verify.quickInfoIs("(constructor) B(a: Foo<I>, b: number): B", undefined);
\ No newline at end of file
+verify.quickInfoIs("constructor B(a: Foo<I>, b: number): B", undefined);
