@@ -12,8 +12,6 @@
 ////    var r/*2*/4 = b.b/*1*/ar; // string
 ////}
 
-diagnostics.setEditValidation(IncrementalEditValidation.None);
-
 goTo.marker('1');
 verify.quickInfoIs("(property) B<string>.bar: string", undefined);
 edit.deleteAtCaret(1);
@@ -24,5 +22,5 @@ edit.backspace(1);
 edit.insert('a');
 verify.quickInfoIs("(property) B<string>.bar: string", undefined);
 goTo.marker('2');
-verify.quickInfoIs("(var) r4: string", undefined);
+verify.quickInfoIs("var r4: string", undefined);
 verify.numberOfErrorsInCurrentFile(0);
