@@ -12,10 +12,10 @@
 ////point./*3*/x = 30;
 
 goTo.marker('1');
-verify.quickInfoIs("(function) makePoint(x: number): {\n    b: number;\n    x: number;\n}", undefined);
+verify.quickInfoIs("function makePoint(x: number): {\n    b: number;\n    x: number;\n}", undefined);
 
 goTo.marker('2');
-verify.quickInfoIs("(var) x: number", undefined);
+verify.quickInfoIs("var x: number", undefined);
 
 goTo.marker('3');
 verify.memberListContains("x", "(property) x: number", undefined);
@@ -23,4 +23,4 @@ verify.memberListContains("b", "(property) b: number", undefined);
 verify.quickInfoIs("(property) x: number", undefined);
 
 goTo.marker('4');
-verify.quickInfoIs("(var) point: {\n    b: number;\n    x: number;\n}", undefined);
\ No newline at end of file
+verify.quickInfoIs("var point: {\n    b: number;\n    x: number;\n}", undefined);
