@@ -10,7 +10,7 @@
 ////point./*2*/x = 30;
 
 goTo.marker('1');
-verify.quickInfoIs("(function) makePoint(x: number): {\n    b: number;\n    x: number;\n}", undefined);
+verify.quickInfoIs("function makePoint(x: number): {\n    b: number;\n    x: number;\n}", undefined);
 
 goTo.marker('2');
 verify.memberListContains("x", "(property) x: number", undefined);
@@ -18,4 +18,4 @@ verify.memberListContains("b", "(property) b: number", undefined);
 verify.quickInfoIs("(property) x: number", undefined);
 
 goTo.marker('3');
-verify.quickInfoIs("(var) point: {\n    b: number;\n    x: number;\n}", undefined);
\ No newline at end of file
+verify.quickInfoIs("var point: {\n    b: number;\n    x: number;\n}", undefined);
