@@ -4,4 +4,4 @@
 ////var /**/foo = new A<number>();
 
 goTo.marker();
-verify.quickInfoIs('(var) foo: A<number>');
+verify.quickInfoIs('var foo: A<number>');
