@@ -17,11 +17,11 @@
 
 
 goTo.marker("1");
-verify.quickInfoIs('(var) x: One | Two');
+verify.quickInfoIs('var x: One | Two');
 
 
 goTo.marker("2");
-verify.quickInfoIs('(property) commonProperty: string | number');
+verify.quickInfoIs('(property) commonProperty: number | string');
 
 goTo.marker("3");
 verify.quickInfoIs('(method) commonFunction(): number');
