@@ -3,4 +3,4 @@
 ////var a = { f: /**/a
 
 goTo.marker();
-verify.quickInfoIs("(var) a: any", null);
\ No newline at end of file
+verify.quickInfoIs("var a: any", null);
