@@ -15,22 +15,22 @@
 ////var f/*7*/f = x.c.c; 
 
 goTo.marker('1');
-verify.quickInfoIs('(var) yy: I<I<I<I<I<I<number>>>>>>');
+verify.quickInfoIs('var yy: I<I<I<I<I<I<number>>>>>>');
 
 goTo.marker('2');
-verify.quickInfoIs('(var) aa: number');
+verify.quickInfoIs('var aa: number');
 
 goTo.marker('3');
-verify.quickInfoIs('(var) bb: I<number>');
+verify.quickInfoIs('var bb: I<number>');
 
 goTo.marker('4');
-verify.quickInfoIs('(var) cc: I<I<number>>');
+verify.quickInfoIs('var cc: I<I<number>>');
 
 goTo.marker('5');
-verify.quickInfoIs('(var) dd: I<number>');
+verify.quickInfoIs('var dd: I<number>');
 
 goTo.marker('6');
-verify.quickInfoIs('(var) ee: I<I<number>>');
+verify.quickInfoIs('var ee: I<I<number>>');
 
 goTo.marker('7');
-verify.quickInfoIs('(var) ff: I<I<I<number>>>');
\ No newline at end of file
+verify.quickInfoIs('var ff: I<I<I<number>>>');
