@@ -6,4 +6,4 @@
 
 goTo.marker();
 verify.completionListContains("A", "import A = require('app')");
-verify.completionListContains("I", "(var) I: number");
\ No newline at end of file
+verify.completionListContains("I", "var I: number");
