@@ -1,4 +1,4 @@
-﻿/// <reference path="fourslash.ts"/>
+/// <reference path="fourslash.ts"/>
 
 ////module /*0*/M {
 ////    export interface /*1*/I {
