@@ -7,4 +7,4 @@
 ////var /**/x = a['artist']; 
 
 goTo.marker();
-verify.quickInfoIs('(var) x: number');
\ No newline at end of file
+verify.quickInfoIs('var x: number');
